@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: analysis.h,v 1.14 2007/12/30 13:05:16 ela Exp $
+ * $Id: analysis.h,v 1.16 2008/02/22 19:46:06 ela Exp $
  *
  */
 
@@ -34,7 +34,6 @@ class net;
 class object;
 class environment;
 class sweep;
-class complex;
 template <class type_t> class ptrlist;
 
 enum analysis_type {
@@ -70,9 +69,9 @@ class analysis : public object
   int  getType (void) { return type; }
   void setType (int t) { type = t; }
   sweep * createSweep (const char *);
-  void saveVariable (const char *, complex, vector *);
+  void saveVariable (const char *, nr_complex_t, vector *);
   bool getProgress (void) { return progress; }
-  void setProgress (int p) { progress = p; }
+  void setProgress (bool p) { progress = p; }
 
  protected:
   int runs;
