@@ -1,7 +1,7 @@
 /*
  * applications.h - the Qucs application list
  *
- * Copyright (C) 2005, 2006, 2007 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2005, 2006, 2007, 2008 Stefan Jahn <stefan@lkcc.org>
  * Copyright (C) 2006 Gunther Kraut <gn.kraut@t-online.de>
  *
  * This is free software; you can redistribute it and/or modify
@@ -19,7 +19,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: applications.h,v 1.27 2007/12/21 23:04:37 ela Exp $
+ * $Id: applications.h,v 1.31 2008/03/27 17:34:29 ela Exp $
  *
  */
 
@@ -636,8 +636,20 @@ struct application_t eqn::applications[] = {
     { TAG_MATVEC, TAG_VECTOR } },
   { "PlotVs", TAG_VECTOR, evaluate::plot_vs_v, 2,
     { TAG_VECTOR, TAG_VECTOR } },
+  { "PlotVs", TAG_VECTOR, evaluate::plot_vs_v, 3,
+    { TAG_VECTOR, TAG_VECTOR, TAG_VECTOR } },
+  { "PlotVs", TAG_VECTOR, evaluate::plot_vs_v, 4,
+    { TAG_VECTOR, TAG_VECTOR, TAG_VECTOR, TAG_VECTOR } },
+  { "PlotVs", TAG_VECTOR, evaluate::plot_vs_v, 5,
+    { TAG_VECTOR, TAG_VECTOR, TAG_VECTOR, TAG_VECTOR, TAG_VECTOR } },
   { "PlotVs", TAG_MATVEC, evaluate::plot_vs_mv, 2,
     { TAG_MATVEC, TAG_VECTOR } },
+  { "PlotVs", TAG_MATVEC, evaluate::plot_vs_mv, 3,
+    { TAG_MATVEC, TAG_VECTOR, TAG_VECTOR } },
+  { "PlotVs", TAG_MATVEC, evaluate::plot_vs_mv, 4,
+    { TAG_MATVEC, TAG_VECTOR, TAG_VECTOR, TAG_VECTOR } },
+  { "PlotVs", TAG_MATVEC, evaluate::plot_vs_mv, 5,
+    { TAG_MATVEC, TAG_VECTOR, TAG_VECTOR, TAG_VECTOR, TAG_VECTOR } },
 
   { "interpolate", TAG_VECTOR, evaluate::interpolate_v_v_d, 3,
     { TAG_VECTOR, TAG_VECTOR, TAG_DOUBLE } },
@@ -861,12 +873,88 @@ struct application_t eqn::applications[] = {
   { "?:", TAG_VECTOR,  evaluate::ifthenelse_v_v, 3,
     { TAG_BOOLEAN, TAG_VECTOR,  TAG_COMPLEX } },
 
+  { "?:", TAG_VECTOR,  evaluate::ifthenelse_v_v_v, 3,
+    { TAG_VECTOR, TAG_VECTOR,  TAG_VECTOR } },
+  { "?:", TAG_VECTOR,  evaluate::ifthenelse_v_v_v, 3,
+    { TAG_VECTOR, TAG_BOOLEAN, TAG_VECTOR } },
+  { "?:", TAG_VECTOR,  evaluate::ifthenelse_v_v_v, 3,
+    { TAG_VECTOR, TAG_DOUBLE,  TAG_VECTOR } },
+  { "?:", TAG_VECTOR,  evaluate::ifthenelse_v_v_v, 3,
+    { TAG_VECTOR, TAG_COMPLEX, TAG_VECTOR } },
+  { "?:", TAG_VECTOR,  evaluate::ifthenelse_v_v_v, 3,
+    { TAG_VECTOR, TAG_VECTOR,  TAG_BOOLEAN } },
+  { "?:", TAG_VECTOR,  evaluate::ifthenelse_v_v_v, 3,
+    { TAG_VECTOR, TAG_VECTOR,  TAG_DOUBLE } },
+  { "?:", TAG_VECTOR,  evaluate::ifthenelse_v_v_v, 3,
+    { TAG_VECTOR, TAG_VECTOR,  TAG_COMPLEX } },
+
   { "<=", TAG_BOOLEAN, evaluate::lessorequal_d_d, 2,
     { TAG_DOUBLE, TAG_DOUBLE } },
+  { "<=", TAG_BOOLEAN, evaluate::lessorequal_d_c, 2,
+    { TAG_DOUBLE,  TAG_COMPLEX } },
+  { "<=", TAG_VECTOR,  evaluate::lessorequal_d_v, 2,
+    { TAG_DOUBLE,  TAG_VECTOR  } },
+  { "<=", TAG_BOOLEAN, evaluate::lessorequal_c_d, 2,
+    { TAG_COMPLEX, TAG_DOUBLE  } },
+  { "<=", TAG_BOOLEAN, evaluate::lessorequal_c_c, 2,
+    { TAG_COMPLEX, TAG_COMPLEX } },
+  { "<=", TAG_VECTOR,  evaluate::lessorequal_c_v, 2,
+    { TAG_COMPLEX, TAG_VECTOR  } },
+  { "<=", TAG_VECTOR,  evaluate::lessorequal_v_d, 2,
+    { TAG_VECTOR,  TAG_DOUBLE  } },
+  { "<=", TAG_VECTOR,  evaluate::lessorequal_v_c, 2,
+    { TAG_VECTOR,  TAG_COMPLEX } },
+  { "<=", TAG_VECTOR,  evaluate::lessorequal_v_v, 2,
+    { TAG_VECTOR,  TAG_VECTOR  } },
+
   { ">=", TAG_BOOLEAN, evaluate::greaterorequal_d_d, 2,
     { TAG_DOUBLE, TAG_DOUBLE } },
-  { "<",  TAG_BOOLEAN, evaluate::less_d_d, 2,     { TAG_DOUBLE, TAG_DOUBLE } },
-  { ">",  TAG_BOOLEAN, evaluate::greater_d_d, 2,  { TAG_DOUBLE, TAG_DOUBLE } },
+  { ">=", TAG_BOOLEAN, evaluate::greaterorequal_d_c, 2,
+    { TAG_DOUBLE,  TAG_COMPLEX } },
+  { ">=", TAG_VECTOR,  evaluate::greaterorequal_d_v, 2,
+    { TAG_DOUBLE,  TAG_VECTOR  } },
+  { ">=", TAG_BOOLEAN, evaluate::greaterorequal_c_d, 2,
+    { TAG_COMPLEX, TAG_DOUBLE  } },
+  { ">=", TAG_BOOLEAN, evaluate::greaterorequal_c_c, 2,
+    { TAG_COMPLEX, TAG_COMPLEX } },
+  { ">=", TAG_VECTOR,  evaluate::greaterorequal_c_v, 2,
+    { TAG_COMPLEX, TAG_VECTOR  } },
+  { ">=", TAG_VECTOR,  evaluate::greaterorequal_v_d, 2,
+    { TAG_VECTOR,  TAG_DOUBLE  } },
+  { ">=", TAG_VECTOR,  evaluate::greaterorequal_v_c, 2,
+    { TAG_VECTOR,  TAG_COMPLEX } },
+  { ">=", TAG_VECTOR,  evaluate::greaterorequal_v_v, 2,
+    { TAG_VECTOR,  TAG_VECTOR  } },
+
+  { "<",  TAG_BOOLEAN, evaluate::less_d_d, 2, { TAG_DOUBLE,  TAG_DOUBLE  } },
+  { "<",  TAG_BOOLEAN, evaluate::less_d_c, 2, { TAG_DOUBLE,  TAG_COMPLEX } },
+  { "<",  TAG_VECTOR,  evaluate::less_d_v, 2, { TAG_DOUBLE,  TAG_VECTOR  } },
+  { "<",  TAG_BOOLEAN, evaluate::less_c_d, 2, { TAG_COMPLEX, TAG_DOUBLE  } },
+  { "<",  TAG_BOOLEAN, evaluate::less_c_c, 2, { TAG_COMPLEX, TAG_COMPLEX } },
+  { "<",  TAG_VECTOR,  evaluate::less_c_v, 2, { TAG_COMPLEX, TAG_VECTOR  } },
+  { "<",  TAG_VECTOR,  evaluate::less_v_d, 2, { TAG_VECTOR,  TAG_DOUBLE  } },
+  { "<",  TAG_VECTOR,  evaluate::less_v_c, 2, { TAG_VECTOR,  TAG_COMPLEX } },
+  { "<",  TAG_VECTOR,  evaluate::less_v_v, 2, { TAG_VECTOR,  TAG_VECTOR  } },
+
+  { ">",  TAG_BOOLEAN, evaluate::greater_d_d, 2,
+    { TAG_DOUBLE, TAG_DOUBLE } },
+  { ">",  TAG_BOOLEAN, evaluate::greater_d_c, 2,
+    { TAG_DOUBLE,  TAG_COMPLEX } },
+  { ">",  TAG_VECTOR,  evaluate::greater_d_v, 2,
+    { TAG_DOUBLE,  TAG_VECTOR  } },
+  { ">",  TAG_BOOLEAN, evaluate::greater_c_d, 2,
+    { TAG_COMPLEX, TAG_DOUBLE  } },
+  { ">",  TAG_BOOLEAN, evaluate::greater_c_c, 2,
+    { TAG_COMPLEX, TAG_COMPLEX } },
+  { ">",  TAG_VECTOR,  evaluate::greater_c_v, 2,
+    { TAG_COMPLEX, TAG_VECTOR  } },
+  { ">",  TAG_VECTOR,  evaluate::greater_v_d, 2,
+    { TAG_VECTOR,  TAG_DOUBLE  } },
+  { ">",  TAG_VECTOR,  evaluate::greater_v_c, 2,
+    { TAG_VECTOR,  TAG_COMPLEX } },
+  { ">",  TAG_VECTOR,  evaluate::greater_v_v, 2,
+    { TAG_VECTOR,  TAG_VECTOR  } },
+
   { "==", TAG_BOOLEAN, evaluate::equal_d_d, 2,    { TAG_DOUBLE, TAG_DOUBLE } },
   { "!=", TAG_BOOLEAN, evaluate::notequal_d_d, 2, { TAG_DOUBLE, TAG_DOUBLE } },
   { "!",  TAG_BOOLEAN, evaluate::not_b, 1,   { TAG_BOOLEAN } },
