@@ -1,7 +1,7 @@
 /*
  * check_netlist.cpp - checker for the Qucs netlist
  *
- * Copyright (C) 2003, 2004, 2005, 2006, 2007 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2003-2008 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: check_netlist.cpp,v 1.116 2007/10/23 17:48:05 ela Exp $
+ * $Id: check_netlist.cpp,v 1.122 2008/02/22 16:55:19 ela Exp $
  *
  */
 
@@ -266,6 +266,9 @@ static struct special_t checker_specials[] = {
   { "Vfile", "Repeat",       { "no", "yes", NULL } },
   { "Ifile", "Interpolator", { "hold", "linear", "cubic", NULL } },
   { "Ifile", "Repeat",       { "no", "yes", NULL } },
+  { "RFEDD", "Type",         { "Y", "Z", "S", "H", "G", "A", "T", NULL } },
+  { "RFEDD", "duringDC",     { "open", "short", "unspecified",
+			       "zerofrequency", NULL } },
   { NULL, NULL, { NULL } }
 };
 
@@ -397,6 +400,10 @@ static int checker_evaluate_scale (struct value_t * value) {
   if (value->scale != NULL) {
     scale = value->scale;
     switch (*scale) {
+    case 'E':
+      scale++; factor = 1e18; break;
+    case 'P':
+      scale++; factor = 1e15; break;
     case 'T':
       scale++; factor = 1e12; break;
     case 'G':
@@ -406,7 +413,16 @@ static int checker_evaluate_scale (struct value_t * value) {
     case 'k':
       scale++; factor = 1e3; break;
     case 'm':
-      scale++; factor = 1e-3; break;
+      scale++;
+      if (*scale == 'i') {
+	scale++;
+	if (*scale == 'l') {
+	  scale++; factor = 2.54e-5;
+	}
+      }
+      else
+	factor = 1e-3;
+      break;
     case 'u':
       scale++; factor = 1e-6; break;
     case 'n':
@@ -414,7 +430,13 @@ static int checker_evaluate_scale (struct value_t * value) {
     case 'p':
       scale++; factor = 1e-12; break;
     case 'f':
-      scale++; factor = 1e-15; break;
+      scale++;
+      if (*scale == 't') {
+	scale++; factor = 0.3048;
+      }
+      else
+	factor = 1e-15;
+      break;
     case 'a':
       scale++; factor = 1e-18; break;
     case 'd':
@@ -424,6 +446,21 @@ static int checker_evaluate_scale (struct value_t * value) {
 	if (*scale == 'm') {
 	  scale++; factor = 1e-3;
 	}
+	else if (*scale == 'u') {
+	  scale++; factor = 1e-6;
+	}
+      }
+      break;
+    case 'i':
+      scale++;
+      if (*scale == 'n') {
+	scale++; factor = 2.54e-2;
+      }
+      break;
+    case 'y':
+      scale++;
+      if (*scale == 'd') {
+	scale++; factor = 0.9144;
       }
       break;
     }
@@ -1637,7 +1674,7 @@ netlist_unchain_definition (struct definition_t * root,
   }
   else {
     // find previous to the candidate to be deleted
-    for (prev = root; prev != NULL && prev->next != cand; prev = prev->next);
+    for (prev = root; prev != NULL && prev->next != cand; prev = prev->next) ;
     if (prev != NULL) {
       prev->next = cand->next;
       netlist_free_definition (cand);
