@@ -1,7 +1,7 @@
 /*
  * inductor.h - inductor class definitions
  *
- * Copyright (C) 2003, 2004 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2003, 2004, 2006 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: inductor.h,v 1.7 2005/06/02 18:17:52 raimi Exp $
+ * $Id: inductor.h,v 1.8 2006/03/27 09:55:50 raimi Exp $
  *
  */
 
@@ -36,6 +36,8 @@ class inductor : public circuit
   void calcAC (nr_double_t);
   void initTR (void);
   void calcTR (nr_double_t);
+  void initHB (void);
+  void calcHB (nr_double_t);
 };
 
 #endif /* __INDUCTOR_H__ */
