@@ -1,7 +1,7 @@
 /*
  * irect.cpp - rectangular pulse current source class implementation
  *
- * Copyright (C) 2004 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2004, 2006 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: irect.cpp,v 1.4 2005/06/02 18:17:52 raimi Exp $
+ * $Id: irect.cpp,v 1.6 2006/09/25 07:45:01 raimi Exp $
  *
  */
 
@@ -34,6 +34,7 @@
 #include "object.h"
 #include "node.h"
 #include "circuit.h"
+#include "net.h"
 #include "component_id.h"
 #include "irect.h"
 
@@ -53,7 +54,12 @@ void irect::initSP (void) {
 void irect::initDC (void) {
   nr_double_t th = getPropertyDouble ("TH");
   nr_double_t tl = getPropertyDouble ("TL");
-  nr_double_t i  = getPropertyDouble ("I") * th / (th + tl);
+  nr_double_t tr = getPropertyDouble ("Tr");
+  nr_double_t tf = getPropertyDouble ("Tf");
+  if (tr > th) tr = th;
+  if (tf > tl) tf = tl;
+  nr_double_t a  = (th + (tf - tr) / 2) / (th + tl);
+  nr_double_t i  = getPropertyDouble ("I") * a;
   allocMatrixMNA ();
   setI (NODE_1, +i); setI (NODE_2, -i);
 }
@@ -71,11 +77,27 @@ void irect::calcTR (nr_double_t t) {
   nr_double_t i  = getPropertyDouble ("I");
   nr_double_t th = getPropertyDouble ("TH");
   nr_double_t tl = getPropertyDouble ("TL");
+  nr_double_t tr = getPropertyDouble ("Tr");
+  nr_double_t tf = getPropertyDouble ("Tf");
+  nr_double_t td = getPropertyDouble ("Td");
   nr_double_t it = 0;
+  nr_double_t s  = getNet()->getSrcFactor ();
 
-  t = t - (th + tl) * floor (t / (th + tl));
-  if (t < th) { // high pulse
-    it = i;
+  if (tr > th) tr = th;
+  if (tf > tl) tf = tl;
+
+  if (t > td) { // after delay
+    t = t - td;
+    t = t - (th + tl) * floor (t / (th + tl));
+    if (t < tr) { // rising edge
+      it = + i / tr * t;
+    }
+    else if (t < th) { // high pulse
+      it = i;
+    }
+    else if (t < th + tf) { // falling edge
+      it = - i / tf * (t - (th + tf));
+    }
   }
-  setI (NODE_1, +it); setI (NODE_2, -it);
+  setI (NODE_1, +it * s); setI (NODE_2, -it * s);
 }
