@@ -19,7 +19,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.
  *
- * $Id: msopen.h,v 1.7 2007/09/16 16:49:40 ela Exp $
+ * $Id: msopen.h,v 1.8 2008/01/10 20:00:01 ela Exp $
  *
  */
 
@@ -36,7 +36,7 @@ class msopen : public circuit
   void calcSP (nr_double_t);
   void initDC (void);
   void calcAC (nr_double_t);
-  complex calcY (nr_double_t);
+  nr_complex_t calcY (nr_double_t);
 };
 
 #endif /* __MSOPEN_H__ */
