@@ -15,10 +15,10 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this package; see the file COPYING.  If not, write to
- * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.  
+ * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
+ * Boston, MA 02110-1301, USA.  
  *
- * $Id: open.cpp,v 1.3 2004/11/24 19:15:49 raimi Exp $
+ * $Id: open.cpp,v 1.5 2005/06/02 18:17:52 raimi Exp $
  *
  */
 
@@ -42,5 +42,5 @@ open::open () : circuit (1) {
 
 void open::initSP (void) {
   allocMatrixS ();
-  setS (1, 1, 1);
+  setS (NODE_1, NODE_1, 1);
 }
