@@ -1,7 +1,7 @@
 /*
  * vac.h - AC voltage source class definitions
  *
- * Copyright (C) 2003, 2004 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2003, 2004, 2006 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: vac.h,v 1.9 2005/06/02 18:17:52 raimi Exp $
+ * $Id: vac.h,v 1.10 2006/03/29 08:02:03 raimi Exp $
  *
  */
 
@@ -34,6 +34,8 @@ class vac : public circuit
   void initAC (void);
   void initTR (void);
   void calcTR (nr_double_t);
+  void initHB (void);
+  void calcHB (nr_double_t);
 };
 
 #endif /* __VAC_H__ */
