@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: vccs.cpp,v 1.17 2006/02/25 14:42:50 raimi Exp $
+ * $Id: vccs.cpp,v 1.18 2008/01/10 20:00:00 ela Exp $
  *
  */
 
@@ -47,8 +47,8 @@ void vccs::calcSP (nr_double_t frequency) {
   nr_double_t g = getPropertyDouble ("G") * z0;
   nr_double_t t = getPropertyDouble ("T");
 
-  complex z1 = polar (2.0 * g, M_PI - 2.0 * M_PI * frequency * t);
-  complex z2 = polar (2.0 * g, - 2.0 * M_PI * frequency * t);
+  nr_complex_t z1 = polar (2.0 * g, M_PI - 2.0 * M_PI * frequency * t);
+  nr_complex_t z2 = polar (2.0 * g, - 2.0 * M_PI * frequency * t);
 
   setS (NODE_1, NODE_1, 1.0); setS (NODE_1, NODE_2, 0.0);
   setS (NODE_1, NODE_3, 0.0); setS (NODE_1, NODE_4, 0.0);
@@ -74,7 +74,8 @@ void vccs::initAC (void) {
 
 void vccs::calcAC (nr_double_t frequency) {
   nr_double_t t = getPropertyDouble ("T");
-  complex g = polar (getPropertyDouble ("G"), - 2.0 * M_PI * frequency * t);
+  nr_complex_t g = polar (getPropertyDouble ("G"),
+			  - 2.0 * M_PI * frequency * t);
   setY (NODE_2, NODE_1, +g); setY (NODE_3, NODE_4, +g);
   setY (NODE_3, NODE_1, -g); setY (NODE_2, NODE_4, -g);
 }
