@@ -1,7 +1,7 @@
 /*
  * vdc.cpp - DC voltage source class implementation
  *
- * Copyright (C) 2003, 2004 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2003, 2004, 2006 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: vdc.cpp,v 1.15 2005/06/02 18:17:52 raimi Exp $
+ * $Id: vdc.cpp,v 1.16 2006/04/05 08:27:06 raimi Exp $
  *
  */
 
@@ -69,3 +69,16 @@ void vdc::initAC (void) {
   initDC ();
   setE (VSRC_1, 0.0);
 }
+
+void vdc::initHB (void) {
+  allocMatrixMNA ();
+  voltageSource (VSRC_1, NODE_1, NODE_2);
+}
+
+void vdc::calcHB (nr_double_t frequency) {
+  if (frequency == 0.0) {
+    setE (VSRC_1, getPropertyDouble ("U"));
+  } else {
+    setE (VSRC_1, 0);
+  }
+}
