@@ -1,7 +1,7 @@
 /*
  * vdc.h - DC voltage source class definitions
  *
- * Copyright (C) 2003, 2004 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2003, 2004, 2006 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: vdc.h,v 1.10 2005/06/02 18:17:52 raimi Exp $
+ * $Id: vdc.h,v 1.11 2006/04/05 08:27:06 raimi Exp $
  *
  */
 
@@ -34,6 +34,8 @@ class vdc : public circuit
   void calcDC (void);
   void initAC (void);
   void initTR (void);
+  void initHB (void);
+  void calcHB (nr_double_t);
 };
 
 #endif /* __VDC_H__ */
