@@ -254,14 +254,15 @@
 #define m00_vt(x)               (kBoverQ*(x))
 #define m10_vt(x)               (kBoverQ)
 
-// $vt and $vt() functions 
-#define _vt_nom                 (kBoverQ)
-
-
 // simulator specific definitions
 #define _modelname              "HBT_X"
 #define _instancename           getName()
-#define _circuit_temp	        (getPropertyDouble ("Temp")+273.15)
+#define _circuit_temp	        (getPropertyDouble("Temp")+273.15)
+#define _param_given(p)		(isPropertyGiven(p)?1:0)
+
+
+// $vt and $vt() functions 
+#define _vt_nom                 (kBoverQ*_circuit_temp)
 
 using namespace device;
 
@@ -275,21 +276,21 @@ HBT_X::HBT_X() : circuit (19)
 void HBT_X::initModel (void)
 {
   // create internal nodes
-  setNode (ei, createInternal (getName (), "ei"));
-  setNode (bi, createInternal (getName (), "bi"));
-  setNode (bii, createInternal (getName (), "bii"));
-  setNode (ci, createInternal (getName (), "ci"));
-  setNode (ex, createInternal (getName (), "ex"));
-  setNode (exx, createInternal (getName (), "exx"));
-  setNode (cx, createInternal (getName (), "cx"));
-  setNode (ni, createInternal (getName (), "ni"));
-  setNode (nii, createInternal (getName (), "nii"));
-  setNode (niix, createInternal (getName (), "niix"));
-  setNode (niii, createInternal (getName (), "niii"));
-  setNode (niiix, createInternal (getName (), "niiix"));
-  setNode (niv, createInternal (getName (), "niv"));
-  setNode (nivx, createInternal (getName (), "nivx"));
-  setNode (ti, createInternal (getName (), "ti"));
+  setInternalNode (ei, "ei");
+  setInternalNode (bi, "bi");
+  setInternalNode (bii, "bii");
+  setInternalNode (ci, "ci");
+  setInternalNode (ex, "ex");
+  setInternalNode (exx, "exx");
+  setInternalNode (cx, "cx");
+  setInternalNode (ni, "ni");
+  setInternalNode (nii, "nii");
+  setInternalNode (niix, "niix");
+  setInternalNode (niii, "niii");
+  setInternalNode (niiix, "niiix");
+  setInternalNode (niv, "niv");
+  setInternalNode (nivx, "nivx");
+  setInternalNode (ti, "ti");
 }
 
 /* Initialization of DC analysis. */
@@ -442,6 +443,9 @@ void HBT_X::calcVerilog (void)
   nr_double_t Ffee = getPropertyDouble ("Ffee");
   nr_double_t Tnom = getPropertyDouble ("Tnom");
 
+  // declare global instance variables
+
+  // declare global model variables
 
 /* ----------------- evaluate verilog analog equations -------------------- */
 
