@@ -249,14 +249,15 @@
 #define m00_vt(x)               (kBoverQ*(x))
 #define m10_vt(x)               (kBoverQ)
 
-// $vt and $vt() functions 
-#define _vt_nom                 (kBoverQ)
-
-
 // simulator specific definitions
 #define _modelname              "mod_amp"
 #define _instancename           getName()
-#define _circuit_temp	        (getPropertyDouble ("Temp")+273.15)
+#define _circuit_temp	        (getPropertyDouble("Temp")+273.15)
+#define _param_given(p)		(isPropertyGiven(p)?1:0)
+
+
+// $vt and $vt() functions 
+#define _vt_nom                 (kBoverQ*_circuit_temp)
 
 using namespace device;
 
@@ -270,17 +271,17 @@ mod_amp::mod_amp() : circuit (14)
 void mod_amp::initModel (void)
 {
   // create internal nodes
-  setNode (n2, createInternal (getName (), "n2"));
-  setNode (n3, createInternal (getName (), "n3"));
-  setNode (n4, createInternal (getName (), "n4"));
-  setNode (n5, createInternal (getName (), "n5"));
-  setNode (n6, createInternal (getName (), "n6"));
-  setNode (n7, createInternal (getName (), "n7"));
-  setNode (n8, createInternal (getName (), "n8"));
-  setNode (n9, createInternal (getName (), "n9"));
-  setNode (n10, createInternal (getName (), "n10"));
-  setNode (n11, createInternal (getName (), "n11"));
-  setNode (n12, createInternal (getName (), "n12"));
+  setInternalNode (n2, "n2");
+  setInternalNode (n3, "n3");
+  setInternalNode (n4, "n4");
+  setInternalNode (n5, "n5");
+  setInternalNode (n6, "n6");
+  setInternalNode (n7, "n7");
+  setInternalNode (n8, "n8");
+  setInternalNode (n9, "n9");
+  setInternalNode (n10, "n10");
+  setInternalNode (n11, "n11");
+  setInternalNode (n12, "n12");
 }
 
 /* Initialization of DC analysis. */
@@ -356,6 +357,9 @@ void mod_amp::calcVerilog (void)
   nr_double_t ILMAX = getPropertyDouble ("ILMAX");
   nr_double_t CSCALE = getPropertyDouble ("CSCALE");
 
+  // declare global instance variables
+
+  // declare global model variables
 
 /* ----------------- evaluate verilog analog equations -------------------- */
 
