@@ -1,7 +1,9 @@
-/* A Bison parser, made by GNU Bison 2.1.  */
+/* A Bison parser, made by GNU Bison 2.3.  */
 
-/* Skeleton parser for Yacc-like parsing with Bison,
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005 Free Software Foundation, Inc.
+/* Skeleton interface for Bison's Yacc-like parsers in C
+
+   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
+   Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -18,10 +20,18 @@
    Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.  */
 
-/* As a special exception, when this file is copied by Bison into a
-   Bison output file, you may use that output file without restriction.
-   This special exception was added by the Free Software Foundation
-   in version 1.24 of Bison.  */
+/* As a special exception, you may create a larger work that contains
+   part or all of the Bison parser skeleton and distribute that work
+   under terms of your choice, so long as that work isn't itself a
+   parser generator using the skeleton or a modified version thereof
+   as a parser skeleton.  Alternatively, if you modify or redistribute
+   the parser skeleton itself, you may (at your option) remove this
+   special exception, which will cause the skeleton and the resulting
+   Bison output files to be licensed under the GNU General Public
+   License without this special exception.
+
+   This special exception was added by the Free Software Foundation in
+   version 2.2 of Bison.  */
 
 /* Tokens.  */
 #ifndef YYTOKENTYPE
@@ -94,7 +104,10 @@
      TF_Action = 320,
      SENS_Action = 321,
      FOUR_Action = 322,
-     OpFunc = 323
+     OpFunc = 323,
+     GE_Type = 324,
+     TC_Special = 325,
+     TEMP_Action = 326
    };
 #endif
 /* Tokens.  */
@@ -164,22 +177,27 @@
 #define SENS_Action 321
 #define FOUR_Action 322
 #define OpFunc 323
+#define GE_Type 324
+#define TC_Special 325
+#define TEMP_Action 326
 
 
 
 
-#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
+#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
+typedef union YYSTYPE
 #line 140 "parse_spice.y"
-typedef union YYSTYPE {
+{
   char * ident;
   char * str;
   double d;
   struct definition_t * definition;
   struct definition_t * subcircuit;
   struct value_t * value;
-} YYSTYPE;
-/* Line 1447 of yacc.c.  */
-#line 183 "tokens_spice.h"
+}
+/* Line 1489 of yacc.c.  */
+#line 200 "tokens_spice.h"
+	YYSTYPE;
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 # define YYSTYPE_IS_TRIVIAL 1
@@ -187,5 +205,3 @@ typedef union YYSTYPE {
 
 extern YYSTYPE spice_lval;
 
-
-
