@@ -1,7 +1,7 @@
 /*
  * equation.cpp - checker for the Qucs equations
  *
- * Copyright (C) 2004, 2005, 2006, 2007 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2004, 2005, 2006, 2007, 2008 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: equation.cpp,v 1.62 2007/09/25 17:39:07 ela Exp $
+ * $Id: equation.cpp,v 1.66 2008/02/17 18:05:35 ela Exp $
  *
  */
 
@@ -88,7 +88,7 @@ constant::constant (const constant & o) : node (o) {
     d = o.d;
     break;
   case TAG_COMPLEX:
-    c = dataref ? o.c : new complex (*o.c);
+    c = dataref ? o.c : new nr_complex_t (*o.c);
     break;
   case TAG_VECTOR:
     v = dataref ? o.v : new vector (*o.v);
@@ -149,7 +149,7 @@ void constant::print (void) {
 }
 
 // Returns the string representation of a complex value.
-static char * Cplx2String (complex c) {
+static char * Cplx2String (nr_complex_t c) {
   static char str[256]; // enough for a real or complex number
   if (imag (c) == 0.0) {
     sprintf (str, "%g", (double) real (c));
@@ -418,11 +418,11 @@ int assignment::evalType (void) {
 constant * assignment::evaluate (void) {
   body->solvee = solvee;
   setResult (body->evaluate ());
-  // inherit drop/prep dependencies
-  if (body->dropdeps) {
-    getResult()->dropdeps = body->dropdeps;
+  // inherit drop/prep dependencies of applications
+  if (body->getResult()->dropdeps) {
+    getResult()->dropdeps = body->getResult()->dropdeps;
     strlist * preps = body->getPrepDependencies ();
-    if (preps) getResult()->addPrepDependencies (preps->get (0));
+    if (preps) getResult()->setPrepDependencies (new strlist (*preps));
   }
   return getResult ();
 }
@@ -754,6 +754,8 @@ int application::findDifferentiator (void) {
    the result. */
 constant * application::evaluate (void) {
   int errors = 0;
+  strlist * apreps = new strlist ();
+
   // first evaluate each argument
   for (node * arg = args; arg != NULL; arg = arg->getNext ()) {
     // FIXME: Can save evaluation of already evaluated equations?
@@ -774,14 +776,19 @@ constant * application::evaluate (void) {
       else {
 	// inherit drop/prep dependencies
 	if (arg->getResult()->dropdeps) {
-	  dropdeps = arg->getResult()->dropdeps;
 	  strlist * preps = arg->getResult()->getPrepDependencies ();
-	  if (preps) addPrepDependencies (preps->get (0));
+	  // recall longest prep dependencies' list of arguments
+	  if (preps && (preps->length () > apreps->length ())) {
+	    delete apreps;
+	    apreps = new strlist (*preps);
+	  }
 	}
 	arg->evaluated++;
       }
     }
   }
+
+  // then evaluate application itself
   if (!errors) {
     node * res;
     // delete previous result if necessary
@@ -794,6 +801,14 @@ constant * application::evaluate (void) {
 		"constant type\n", toString ());
     }
   }
+
+  // inherit prep dependencies of arguments if necessary
+  if (!getResult()->dropdeps && apreps->length () > 0) {
+    getResult()->dropdeps = 1;
+    getResult()->appendPrepDependencies (apreps);
+  }
+  delete apreps;
+
   return getResult ();
 }
 
@@ -898,7 +913,7 @@ int node::count (void) {
 void node::append (node * last) {
   if (!last) return;
   node * n;
-  for (n = this; n->getNext () != NULL; n = n->getNext ());
+  for (n = this; n->getNext () != NULL; n = n->getNext ()) ;
   last->setNext (NULL);
   n->setNext (last);
 }
@@ -907,14 +922,14 @@ void node::append (node * last) {
 void node::appendNodes (node * last) {
   if (!last) return;
   node * n;
-  for (n = this; n->getNext () != NULL; n = n->getNext ());
+  for (n = this; n->getNext () != NULL; n = n->getNext ()) ;
   n->setNext (last);
 }
 
 // Returns the equation node at the given argument position.
 node * node::get (int pos) {
   node * n = this;
-  for (int i = 0; i < pos && n != NULL; n = n->getNext (), i++);
+  for (int i = 0; i < pos && n != NULL; n = n->getNext (), i++) ;
   return n;
 }
 
@@ -926,7 +941,7 @@ void node::setResult (constant * r) {
 // Returns the constant equation node at the given argument position.
 constant * node::getResult (int pos) {
   node * n = this;
-  for (int i = 0; i < pos && n != NULL; n = n->getNext (), i++);
+  for (int i = 0; i < pos && n != NULL; n = n->getNext (), i++) ;
   return n ? n->getResult () : NULL;
 }
 
@@ -947,6 +962,23 @@ nr_double_t node::getResultDouble (void) {
   return 0.0;
 }
 
+/* Returns a complex value depending on the type of the equation nodes
+   result type. */
+nr_complex_t node::getResultComplex (void) {
+  constant * c = getResult ();
+  if (c != NULL) {
+    switch (getType ()) {
+    case TAG_DOUBLE:
+      return rect (c->d, 0.0); break;
+    case TAG_COMPLEX:
+      return *(c->c); break;
+    case TAG_BOOLEAN:
+      return c->b ? 1.0 : 0.0; break;
+    }
+  }
+  return 0.0;
+}
+
 // Assigns the dependency list to the equation node object.
 void node::setDependencies (strlist * depends) {
   if (dependencies) delete dependencies;
@@ -1024,6 +1056,13 @@ void node::addPrepDependencies (char * dep) {
   prepDependencies->add (dep);
 }
 
+/* This function appends the given dependency list to the list of
+   dependencies which are going to be prepend. */
+void node::appendPrepDependencies (strlist * deps) {
+  if (prepDependencies == NULL) prepDependencies = new strlist ();
+  prepDependencies->append (deps);
+}
+
 /* The function sets the data dependency list of the equation node. */
 void node::setDataDependencies (strlist * deps) {
   if (dataDependencies != NULL) delete dataDependencies;
@@ -1388,7 +1427,7 @@ node * checker::appendEquation (node * root, node * last) {
 // Returns the last node in the given equation root.
 node * checker::lastEquation (node * root) {
   node * eqn;
-  for (eqn = root; eqn && eqn->getNext () != NULL; eqn = eqn->getNext ());
+  for (eqn = root; eqn && eqn->getNext () != NULL; eqn = eqn->getNext ()) ;
   return eqn;
 }
 
@@ -1399,7 +1438,7 @@ void checker::dropEquation (node * eqn) {
   }
   else {
     node * prev;
-    for (prev = equations; prev->getNext () != eqn; prev = prev->getNext());
+    for (prev = equations; prev->getNext () != eqn; prev = prev->getNext()) ;
     prev->setNext (eqn->getNext ());
   }
 }
@@ -1847,10 +1886,10 @@ strlist * solver::collectDataDependencies (node * eqn) {
   // prepend dependencies if necessary
   strlist * preps = eqn->getResult()->getPrepDependencies ();
   if (datadeps) {
-    if (preps) datadeps->add (preps->last ());
+    if (preps) datadeps->add (preps);
   } else {
     datadeps = new strlist ();
-    if (preps) datadeps->add (preps->last ());
+    if (preps) datadeps->add (preps);
   }
   // drop duplicate entries
   datadeps = checker::foldDependencies (datadeps);
@@ -2015,6 +2054,15 @@ node * checker::addDouble (const char * type, const char * ident,
   return eqn;
 }
 
+/* The function adds a new equation to the equation checker consisting
+   of an assignment of a complex variable. */
+node * checker::addComplex (const char * type, const char * ident,
+			    nr_complex_t value) {
+  node * eqn = createComplex (type, ident, value);
+  addEquation (eqn);
+  return eqn;
+}
+
 // Adds given equation to the equation list.
 void checker::addEquation (node * eqn) {
   eqn->setNext (equations);
@@ -2049,6 +2097,24 @@ node * checker::createDouble (const char * type, const char * ident,
   return a;
 }
 
+/* This function creates a equation consisting of an assignment of a
+   complex variable. */
+node * checker::createComplex (const char * type, const char * ident,
+			       nr_complex_t value) {
+  // create constant double value
+  constant * c = new constant (TAG_COMPLEX);
+  c->checkee = this;
+  c->c = new nr_complex_t (value);
+  // create the appropriate assignment
+  assignment * a = new assignment ();
+  a->checkee = this;
+  a->result = strdup (ident);
+  a->body = c;
+  a->output = 0;
+  a->setInstance (type);
+  return a;
+}
+
 /* This function creates a equation consisting of an assignment of a
    reference. */
 node * checker::createReference (const char * type, char * ident,
