@@ -1,7 +1,7 @@
 /*
  * input.cpp - input netlist class implementation
  *
- * Copyright (C) 2003, 2004, 2005, 2006, 2007 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2003-2008 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: input.cpp,v 1.76 2007/12/18 21:15:47 ela Exp $
+ * $Id: input.cpp,v 1.83 2008/04/01 14:52:04 ela Exp $
  *
  */
 
@@ -417,6 +417,14 @@ circuit * input::createCircuit (char * type) {
     return new diode ();
   else if (!strcmp (type, "EDD"))
     return new eqndefined ();
+  else if (!strcmp (type, "RFEDD"))
+    return new rfedd ();
+  else if (!strcmp (type, "Diac"))
+    return new diac ();
+  else if (!strcmp (type, "SCR"))
+    return new thyristor ();
+  else if (!strcmp (type, "Triac"))
+    return new triac ();
   else if (!strcmp (type, "MLIN"))
     return new msline ();
   else if (!strcmp (type, "MCORN"))
@@ -505,6 +513,14 @@ circuit * input::createCircuit (char * type) {
     return new mod_amp ();
   else if (!strcmp (type, "hic2_full"))
     return new hic2_full ();
+  else if (!strcmp (type, "log_amp"))
+    return new log_amp ();
+  else if (!strcmp (type, "hic0_full"))
+    return new hic0_full ();
+  else if (!strcmp (type, "potentiometer"))
+    return new potentiometer ();
+  else if (!strcmp (type, "MESFET"))
+    return new MESFET ();
 
   logprint (LOG_ERROR, "no such circuit type `%s'\n", type);
   return NULL;
