@@ -1,7 +1,7 @@
 /*
  * net.h - net class definitions
  *
- * Copyright (C) 2003, 2004, 2005, 2006 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2003, 2004, 2005, 2006, 2007 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: net.h,v 1.17 2006/08/09 08:32:18 raimi Exp $
+ * $Id: net.h,v 1.19 2007/12/28 20:08:47 ela Exp $
  *
  */
 
@@ -38,7 +38,7 @@ class net : public object
 {
  public:
   net ();
-  net (char *);
+  net (const char *);
   net (net &);
   ~net ();
   circuit * getRoot (void) { return root; }
@@ -55,7 +55,7 @@ class net : public object
   void insertedNode (node *);
   void insertAnalysis (analysis *);
   void removeAnalysis (analysis *);
-  dataset * runAnalysis (void);
+  dataset * runAnalysis (int &);
   void getDroppedCircuits (nodelist * nodes = NULL);
   void deleteUnusedCircuits (nodelist * nodes = NULL);
   int  getPorts (void) { return nPorts; }
