@@ -1,7 +1,7 @@
 /*
  * parasweep.h - parameter sweep class definitions
  *
- * Copyright (C) 2004 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2004, 2007 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: parasweep.h,v 1.5 2005/06/02 18:17:51 raimi Exp $
+ * $Id: parasweep.h,v 1.7 2007/12/28 20:08:47 ela Exp $
  *
  */
 
@@ -36,12 +36,15 @@ class parasweep : public analysis
   parasweep (char *);
   parasweep (parasweep &);
   ~parasweep ();
-  void solve (void);
+  int  initialize (void);
+  int  solve (void);
+  int  cleanup (void);
   void saveResults (void);
 
  private:
   variable * var;
   sweep * swp;
+  void * eqn;
 };
 
 #endif /* __PARASWEEP_H__ */
