@@ -152,7 +152,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: parse_netlist.y,v 1.28 2007/10/22 17:53:10 ela Exp $
+ * $Id: parse_netlist.y,v 1.29 2008/01/10 20:00:00 ela Exp $
  *
  */
 
@@ -1993,7 +1993,7 @@ yyreduce:
 #line 381 "parse_netlist.y"
     {
     (yyval.con) = new eqn::constant (eqn::TAG_COMPLEX);
-    (yyval.con)->c = new complex (0.0, (yyvsp[(1) - (1)].d));
+    (yyval.con)->c = new nr_complex_t (0.0, (yyvsp[(1) - (1)].d));
   }
     break;
 
