@@ -1,7 +1,7 @@
 /*
  * qucsdefs.h - netlist definitions for the Qucs netlists
  *
- * Copyright (C) 2004, 2005, 2006, 2007 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2004, 2005, 2006, 2007, 2008 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: qucsdefs.h,v 1.77 2007/12/20 21:02:09 ela Exp $
+ * $Id: qucsdefs.h,v 1.87 2008/04/01 14:52:06 ela Exp $
  *
  */
 
@@ -54,7 +54,7 @@ struct define_t qucs_definition_available[] =
   { "MUT", 4, PROP_COMPONENT, PROP_NO_SUBSTRATE, PROP_LINEAR,
     { { "L1", PROP_REAL, { 1e-3, PROP_NO_STR },	PROP_POS_RANGEX },
       { "L2", PROP_REAL, { 1e-3, PROP_NO_STR },	PROP_POS_RANGEX },
-      { "k", PROP_REAL, { 0.9, PROP_NO_STR }, { '[', 0, 1, '[' } },
+      { "k", PROP_REAL, { 0.9, PROP_NO_STR }, { ']', -1, 1, '[' } },
       PROP_NO_PROP },
     { PROP_NO_PROP }
   },
@@ -63,9 +63,9 @@ struct define_t qucs_definition_available[] =
     { { "L1", PROP_REAL, { 1e-3, PROP_NO_STR },	PROP_POS_RANGEX },
       { "L2", PROP_REAL, { 1e-3, PROP_NO_STR },	PROP_POS_RANGEX },
       { "L3", PROP_REAL, { 1e-3, PROP_NO_STR },	PROP_POS_RANGEX },
-      { "k12", PROP_REAL, { 0.9, PROP_NO_STR }, { '[', 0, 1, '[' } },
-      { "k13", PROP_REAL, { 0.9, PROP_NO_STR }, { '[', 0, 1, '[' } },
-      { "k23", PROP_REAL, { 0.9, PROP_NO_STR }, { '[', 0, 1, '[' } },
+      { "k12", PROP_REAL, { 0.9, PROP_NO_STR }, { ']', -1, 1, '[' } },
+      { "k13", PROP_REAL, { 0.9, PROP_NO_STR }, { ']', -1, 1, '[' } },
+      { "k23", PROP_REAL, { 0.9, PROP_NO_STR }, { ']', -1, 1, '[' } },
       PROP_NO_PROP },
     { PROP_NO_PROP }
   },
@@ -590,7 +590,7 @@ struct define_t qucs_definition_available[] =
       { "Rg", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
       { "L", PROP_REAL, { 100e-6, PROP_NO_STR }, PROP_RNG_X01I },
       { "Ld", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
-      { "W", PROP_REAL, { 100e-6, PROP_NO_STR }, PROP_RNG_X01I },
+      { "W", PROP_REAL, { 100e-6, PROP_NO_STR }, PROP_POS_RANGEX },
       { "Tox", PROP_REAL, { 1e-7, PROP_NO_STR }, PROP_RNG_X01I },
       { "Cgso", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
       { "Cgdo", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
@@ -646,6 +646,115 @@ struct define_t qucs_definition_available[] =
       { "Q8", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE }, 
       PROP_NO_PROP }
   },
+  /* equation defined RF device */
+  { "RFEDD", PROP_NODES, PROP_COMPONENT, PROP_NO_SUBSTRATE, PROP_LINEAR,
+    { { "Type", PROP_STR, { PROP_NO_VAL, "Y" }, PROP_NO_RANGE },
+      { "duringDC", PROP_STR, { PROP_NO_VAL, "open" }, PROP_NO_RANGE },
+      { "P11", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE },
+      PROP_NO_PROP },
+    { { "P12", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE }, 
+      { "P13", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE }, 
+      { "P14", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE }, 
+      { "P15", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE }, 
+      { "P16", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE }, 
+      { "P17", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE }, 
+      { "P18", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE }, 
+      { "P21", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE },
+      { "P22", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE }, 
+      { "P23", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE }, 
+      { "P24", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE }, 
+      { "P25", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE }, 
+      { "P26", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE }, 
+      { "P27", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE }, 
+      { "P28", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE }, 
+      { "P31", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE },
+      { "P32", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE }, 
+      { "P33", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE }, 
+      { "P34", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE }, 
+      { "P35", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE }, 
+      { "P36", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE }, 
+      { "P37", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE }, 
+      { "P38", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE }, 
+      { "P41", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE },
+      { "P42", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE }, 
+      { "P43", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE }, 
+      { "P44", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE }, 
+      { "P45", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE }, 
+      { "P46", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE }, 
+      { "P47", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE }, 
+      { "P48", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE }, 
+      { "P51", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE },
+      { "P52", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE }, 
+      { "P53", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE }, 
+      { "P54", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE }, 
+      { "P55", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE }, 
+      { "P56", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE }, 
+      { "P57", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE }, 
+      { "P58", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE }, 
+      { "P61", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE },
+      { "P62", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE }, 
+      { "P63", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE }, 
+      { "P64", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE }, 
+      { "P65", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE }, 
+      { "P66", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE }, 
+      { "P67", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE }, 
+      { "P68", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE }, 
+      { "P71", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE },
+      { "P72", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE }, 
+      { "P73", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE }, 
+      { "P74", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE }, 
+      { "P75", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE }, 
+      { "P76", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE }, 
+      { "P77", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE }, 
+      { "P78", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE }, 
+      { "P81", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE },
+      { "P82", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE }, 
+      { "P83", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE }, 
+      { "P84", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE }, 
+      { "P85", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE }, 
+      { "P86", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE }, 
+      { "P87", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE }, 
+      { "P88", PROP_REAL, { 0, PROP_NO_STR }, PROP_NO_RANGE }, 
+      PROP_NO_PROP }
+  },
+  /* diac */
+  { "Diac", 2, PROP_COMPONENT, PROP_NO_SUBSTRATE, PROP_NONLINEAR,
+    { { "Ibo", PROP_REAL, { 50e-6, PROP_NO_STR }, PROP_POS_RANGEX }, 
+      { "Vbo", PROP_REAL, { 30, PROP_NO_STR }, PROP_POS_RANGEX }, 
+      PROP_NO_PROP },
+    { { "Cj0", PROP_REAL, { 10e-12, PROP_NO_STR }, PROP_POS_RANGE }, 
+      { "Is", PROP_REAL, { 1e-10, PROP_NO_STR }, PROP_POS_RANGE }, 
+      { "N", PROP_REAL, { 2.0, PROP_NO_STR }, { '[', 0.1, 100, ']' } },
+      { "Ri", PROP_REAL, { 10.0, PROP_NO_STR }, PROP_POS_RANGEX },
+      { "Temp", PROP_REAL, { 26.85, PROP_NO_STR }, PROP_MIN_VAL (K) },
+      PROP_NO_PROP }
+  },
+  /* triac */
+  { "Triac", 3, PROP_COMPONENT, PROP_NO_SUBSTRATE, PROP_NONLINEAR,
+    { { "Igt", PROP_REAL, { 50e-6, PROP_NO_STR }, PROP_POS_RANGEX }, 
+      { "Vbo", PROP_REAL, { 30, PROP_NO_STR }, PROP_POS_RANGEX }, 
+      PROP_NO_PROP },
+    { { "Cj0", PROP_REAL, { 10e-12, PROP_NO_STR }, PROP_POS_RANGE }, 
+      { "Is", PROP_REAL, { 1e-10, PROP_NO_STR }, PROP_POS_RANGE }, 
+      { "N", PROP_REAL, { 2.0, PROP_NO_STR }, { '[', 0.1, 100, ']' } },
+      { "Ri", PROP_REAL, { 10.0, PROP_NO_STR }, PROP_POS_RANGEX },
+      { "Rg", PROP_REAL, { 5.0, PROP_NO_STR }, PROP_POS_RANGEX },
+      { "Temp", PROP_REAL, { 26.85, PROP_NO_STR }, PROP_MIN_VAL (K) },
+      PROP_NO_PROP }
+  },
+  /* thyristor */
+  { "SCR", 3, PROP_COMPONENT, PROP_NO_SUBSTRATE, PROP_NONLINEAR,
+    { { "Igt", PROP_REAL, { 50e-6, PROP_NO_STR }, PROP_POS_RANGEX }, 
+      { "Vbo", PROP_REAL, { 30, PROP_NO_STR }, PROP_POS_RANGEX }, 
+      PROP_NO_PROP },
+    { { "Cj0", PROP_REAL, { 10e-12, PROP_NO_STR }, PROP_POS_RANGE }, 
+      { "Is", PROP_REAL, { 1e-10, PROP_NO_STR }, PROP_POS_RANGE }, 
+      { "N", PROP_REAL, { 2.0, PROP_NO_STR }, { '[', 0.1, 100, ']' } },
+      { "Ri", PROP_REAL, { 10.0, PROP_NO_STR }, PROP_POS_RANGEX },
+      { "Rg", PROP_REAL, { 5.0, PROP_NO_STR }, PROP_POS_RANGEX },
+      { "Temp", PROP_REAL, { 26.85, PROP_NO_STR }, PROP_MIN_VAL (K) },
+      PROP_NO_PROP }
+  },
 
   /* hicumL2p1 verilog device */
   { "hicumL2p1", 5, PROP_COMPONENT, PROP_NO_SUBSTRATE, PROP_NONLINEAR,
@@ -984,6 +1093,198 @@ struct define_t qucs_definition_available[] =
       PROP_NO_PROP },
     { PROP_NO_PROP }
   },
+  /* log_amp verilog device */
+  { "log_amp", 3, PROP_COMPONENT, PROP_NO_SUBSTRATE, PROP_NONLINEAR,
+    {
+      { "Kv", PROP_REAL, { 1.0, PROP_NO_STR }, { '.', 0, 0, '.' } },
+      { "Dk", PROP_REAL, { 0.3, PROP_NO_STR }, { '[', (-100), 100, ']' } },
+      { "Ib1", PROP_REAL, { 5e-12, PROP_NO_STR }, { '.', 0, 0, '.' } },
+      { "Ibr", PROP_REAL, { 5e-12, PROP_NO_STR }, { '.', 0, 0, '.' } },
+      { "M", PROP_REAL, { 5, PROP_NO_STR }, { '[', 1, 0, '.' } },
+      { "N", PROP_REAL, { 0.1, PROP_NO_STR }, { '[', 0, 100, ']' } },
+      { "Vosout", PROP_REAL, { 3e-3, PROP_NO_STR }, { '.', 0, 0, '.' } },
+      { "Rinp", PROP_REAL, { 1e6, PROP_NO_STR }, { '[', 1, 0, '.' } },
+      { "Fc", PROP_REAL, { 1e3, PROP_NO_STR }, { '[', 1, 0, '.' } },
+      { "Ro", PROP_REAL, { 1e-3, PROP_NO_STR }, { '[', 1e-3, 0, '.' } },
+      { "Ntc", PROP_REAL, { 0.002, PROP_NO_STR }, { '[', (-100), 100, ']' } },
+      { "Vosouttc", PROP_REAL, { 80e-6, PROP_NO_STR }, { '.', 0, 0, '.' } },
+      { "Dktc", PROP_REAL, { 0.03, PROP_NO_STR }, { '[', (-100), 100, ']' } },
+      { "Ib1tc", PROP_REAL, { 0.5e-12, PROP_NO_STR }, { '.', 0, 0, '.' } },
+      { "Ibrtc", PROP_REAL, { 0.5e-12, PROP_NO_STR }, { '.', 0, 0, '.' } },
+      { "Tnom", PROP_REAL, { 26.85, PROP_NO_STR }, { '[', (-273), 0, '.' } },
+      { "Temp", PROP_REAL, { 26.85, PROP_NO_STR }, PROP_MIN_VAL (K) },
+      PROP_NO_PROP },
+    { PROP_NO_PROP }
+  },
+  /* hic0_full verilog device */
+  { "hic0_full", 5, PROP_COMPONENT, PROP_NO_SUBSTRATE, PROP_NONLINEAR,
+    {
+      { "is", PROP_REAL, { 1.0e-16, PROP_NO_STR }, { '[', 0, 1, ']' } },
+      { "mcf", PROP_REAL, { 1.00, PROP_NO_STR }, { ']', 0, 10, ']' } },
+      { "mcr", PROP_REAL, { 1.00, PROP_NO_STR }, { ']', 0, 10, ']' } },
+      { "vef", PROP_REAL, { 1.0e6, PROP_NO_STR }, { ']', 0, 1.0e6, ']' } },
+      { "iqf", PROP_REAL, { 1.0e6, PROP_NO_STR }, { ']', 0, 1.0e6, ']' } },
+      { "iqr", PROP_REAL, { 1.0e6, PROP_NO_STR }, { ']', 0, 1.0e6, ']' } },
+      { "iqfh", PROP_REAL, { 1.0e6, PROP_NO_STR }, { ']', 0, 1.0e6, ']' } },
+      { "tfh", PROP_REAL, { 1.0e6, PROP_NO_STR }, { ']', 0, 1.0e6, ']' } },
+      { "ibes", PROP_REAL, { 1e-18, PROP_NO_STR }, { '[', 0, 1, ']' } },
+      { "mbe", PROP_REAL, { 1.0, PROP_NO_STR }, { ']', 0, 10, ']' } },
+      { "ires", PROP_REAL, { 0.0, PROP_NO_STR }, { '[', 0, 1, ']' } },
+      { "mre", PROP_REAL, { 2.0, PROP_NO_STR }, { ']', 0, 10, ']' } },
+      { "ibcs", PROP_REAL, { 0.0, PROP_NO_STR }, { '[', 0, 1, ']' } },
+      { "mbc", PROP_REAL, { 1.0, PROP_NO_STR }, { ']', 0, 10, ']' } },
+      { "cje0", PROP_REAL, { 1.0e-20, PROP_NO_STR }, { ']', 0, 1.0e6, '[' } },
+      { "vde", PROP_REAL, { 0.9, PROP_NO_STR }, { ']', 0, 10, ']' } },
+      { "ze", PROP_REAL, { 0.5, PROP_NO_STR }, { ']', 0, 1, ']' } },
+      { "aje", PROP_REAL, { 2.5, PROP_NO_STR }, { '[', 1, 1.0e6, '[' } },
+      { "t0", PROP_REAL, { 0.0, PROP_NO_STR }, { '[', 0, 1.0e6, '[' } },
+      { "dt0h", PROP_REAL, { 0.0, PROP_NO_STR }, { '[', 0, 1.0e6, '[' } },
+      { "tbvl", PROP_REAL, { 0.0, PROP_NO_STR }, { '[', 0, 1.0e6, '[' } },
+      { "tef0", PROP_REAL, { 0.0, PROP_NO_STR }, { '[', 0, 1.0e6, '[' } },
+      { "gte", PROP_REAL, { 1.0, PROP_NO_STR }, { ']', 0, 10, ']' } },
+      { "thcs", PROP_REAL, { 0.0, PROP_NO_STR }, { '[', 0, 1.0e6, '[' } },
+      { "ahc", PROP_REAL, { 0.1, PROP_NO_STR }, { ']', 0, 10, ']' } },
+      { "tr", PROP_REAL, { 0.0, PROP_NO_STR }, { '[', 0, 1.0e6, '[' } },
+      { "rci0", PROP_REAL, { 150, PROP_NO_STR }, { ']', 0, 1.0e6, '[' } },
+      { "vlim", PROP_REAL, { 0.5, PROP_NO_STR }, { ']', 0, 10, ']' } },
+      { "vpt", PROP_REAL, { 100, PROP_NO_STR }, { ']', 0, 100, ']' } },
+      { "vces", PROP_REAL, { 0.1, PROP_NO_STR }, { '[', 0, 1, ']' } },
+      { "cjci0", PROP_REAL, { 1.0e-20, PROP_NO_STR }, { ']', 0, 1.0e6, '[' } },
+      { "vdci", PROP_REAL, { 0.7, PROP_NO_STR }, { ']', 0, 10, ']' } },
+      { "zci", PROP_REAL, { 0.333, PROP_NO_STR }, { ']', 0, 1, ']' } },
+      { "vptci", PROP_REAL, { 100, PROP_NO_STR }, { ']', 0, 100, ']' } },
+      { "cjcx0", PROP_REAL, { 1.0e-20, PROP_NO_STR }, { '[', 0, 1.0e6, '[' } },
+      { "vdcx", PROP_REAL, { 0.7, PROP_NO_STR }, { ']', 0, 10, ']' } },
+      { "zcx", PROP_REAL, { 0.333, PROP_NO_STR }, { ']', 0, 1, ']' } },
+      { "vptcx", PROP_REAL, { 100, PROP_NO_STR }, { ']', 0, 100, ']' } },
+      { "fbc", PROP_REAL, { 1.0, PROP_NO_STR }, { '[', 0, 1, ']' } },
+      { "rbi0", PROP_REAL, { 0.0, PROP_NO_STR }, { '[', 0, 1.0e6, '[' } },
+      { "vr0e", PROP_REAL, { 2.5, PROP_NO_STR }, { ']', 0, 1.0e6, ']' } },
+      { "vr0c", PROP_REAL, { 1.0e6, PROP_NO_STR }, { ']', 0, 1.0e6, ']' } },
+      { "fgeo", PROP_REAL, { 0.656, PROP_NO_STR }, { '[', 0, 1.0e6, ']' } },
+      { "rbx", PROP_REAL, { 0.0, PROP_NO_STR }, { '[', 0, 1.0e6, '[' } },
+      { "rcx", PROP_REAL, { 0.0, PROP_NO_STR }, { '[', 0, 1.0e6, '[' } },
+      { "re", PROP_REAL, { 0.0, PROP_NO_STR }, { '[', 0, 1.0e6, '[' } },
+      { "itss", PROP_REAL, { 0.0, PROP_NO_STR }, { '[', 0, 1.0, ']' } },
+      { "msf", PROP_REAL, { 1.0, PROP_NO_STR }, { ']', 0, 10, ']' } },
+      { "iscs", PROP_REAL, { 0.0, PROP_NO_STR }, { '[', 0, 1.0, ']' } },
+      { "msc", PROP_REAL, { 1.0, PROP_NO_STR }, { ']', 0, 10, ']' } },
+      { "cjs0", PROP_REAL, { 1.0e-20, PROP_NO_STR }, { '[', 0, 1.0e6, '[' } },
+      { "vds", PROP_REAL, { 0.3, PROP_NO_STR }, { ']', 0, 10, ']' } },
+      { "zs", PROP_REAL, { 0.3, PROP_NO_STR }, { ']', 0, 1, ']' } },
+      { "vpts", PROP_REAL, { 100, PROP_NO_STR }, { ']', 0, 100, ']' } },
+      { "cbcpar", PROP_REAL, { 0.0, PROP_NO_STR }, { '[', 0, 1.0e6, '[' } },
+      { "cbepar", PROP_REAL, { 0.0, PROP_NO_STR }, { '[', 0, 1.0e6, '[' } },
+      { "eavl", PROP_REAL, { 0.0, PROP_NO_STR }, { '[', 0, 0, '.' } },
+      { "kavl", PROP_REAL, { 0.0, PROP_NO_STR }, { '[', 0, 1.0e6, '[' } },
+      { "kf", PROP_REAL, { 0.0, PROP_NO_STR }, { '[', 0, 1.0e6, '[' } },
+      { "af", PROP_REAL, { 2.0, PROP_NO_STR }, { ']', 0, 10, ']' } },
+      { "vgb", PROP_REAL, { 1.2, PROP_NO_STR }, { ']', 0, 10, ']' } },
+      { "vge", PROP_REAL, { 1.17, PROP_NO_STR }, { ']', 0, 10, ']' } },
+      { "vgc", PROP_REAL, { 1.17, PROP_NO_STR }, { ']', 0, 10, ']' } },
+      { "vgs", PROP_REAL, { 1.17, PROP_NO_STR }, { ']', 0, 10, ']' } },
+      { "f1vg", PROP_REAL, { (-1.02377e-4), PROP_NO_STR }, PROP_NO_RANGE },
+      { "f2vg", PROP_REAL, { 4.3215e-4, PROP_NO_STR }, PROP_NO_RANGE },
+      { "alt0", PROP_REAL, { 0.0, PROP_NO_STR }, PROP_NO_RANGE },
+      { "kt0", PROP_REAL, { 0.0, PROP_NO_STR }, PROP_NO_RANGE },
+      { "zetact", PROP_REAL, { 3.0, PROP_NO_STR }, PROP_NO_RANGE },
+      { "zetabet", PROP_REAL, { 3.5, PROP_NO_STR }, PROP_NO_RANGE },
+      { "zetaci", PROP_REAL, { 0.0, PROP_NO_STR }, PROP_NO_RANGE },
+      { "alvs", PROP_REAL, { 0.0, PROP_NO_STR }, PROP_NO_RANGE },
+      { "alces", PROP_REAL, { 0.0, PROP_NO_STR }, PROP_NO_RANGE },
+      { "zetarbi", PROP_REAL, { 0.0, PROP_NO_STR }, PROP_NO_RANGE },
+      { "zetarbx", PROP_REAL, { 0.0, PROP_NO_STR }, PROP_NO_RANGE },
+      { "zetarcx", PROP_REAL, { 0.0, PROP_NO_STR }, PROP_NO_RANGE },
+      { "zetare", PROP_REAL, { 0.0, PROP_NO_STR }, PROP_NO_RANGE },
+      { "alkav", PROP_REAL, { 0.0, PROP_NO_STR }, PROP_NO_RANGE },
+      { "aleav", PROP_REAL, { 0.0, PROP_NO_STR }, PROP_NO_RANGE },
+      { "flsh", PROP_INT, { 0, PROP_NO_STR }, { '[', 0, 2, ']' } },
+      { "rth", PROP_REAL, { 0.0, PROP_NO_STR }, { '[', 0, 1.0e6, '[' } },
+      { "cth", PROP_REAL, { 0.0, PROP_NO_STR }, { '[', 0, 1.0e6, '[' } },
+      { "tnom", PROP_REAL, { 27, PROP_NO_STR }, PROP_NO_RANGE },
+      { "dt", PROP_REAL, { 0.0, PROP_NO_STR }, PROP_NO_RANGE },
+      PROP_NO_PROP },
+    {
+      { "npn", PROP_INT, { 1, PROP_NO_STR }, PROP_POS_RANGE },
+      { "pnp", PROP_INT, { 0, PROP_NO_STR }, PROP_POS_RANGE },
+      { "Temp", PROP_REAL, { 26.85, PROP_NO_STR }, PROP_MIN_VAL (K) },
+      PROP_NO_PROP }
+  },
+  /* potentiometer verilog device */
+  { "potentiometer", 3, PROP_COMPONENT, PROP_NO_SUBSTRATE, PROP_NONLINEAR,
+    {
+      { "R_pot", PROP_REAL, { 1e4, PROP_NO_STR }, { '[', 1e-6, 0, '.' } },
+      { "Rotation", PROP_REAL, { 120, PROP_NO_STR }, { '[', 0, 0, '.' } },
+      { "Taper_Coeff", PROP_REAL, { 0, PROP_NO_STR }, { '[', 0, 0, '.' } },
+      { "LEVEL", PROP_INT, { 1, PROP_NO_STR }, { '[', 1, 3, ']' } },
+      { "Max_Rotation", PROP_REAL, { 240.0, PROP_NO_STR }, { '[', 0, 0, '.' } },
+      { "Conformity", PROP_REAL, { 0.2, PROP_NO_STR }, { '.', 0, 0, '.' } },
+      { "Linearity", PROP_REAL, { 0.2, PROP_NO_STR }, { '.', 0, 0, '.' } },
+      { "Contact_Res", PROP_REAL, { 1, PROP_NO_STR }, { '[', 1e-6, 0, '.' } },
+      { "Temp_Coeff", PROP_REAL, { 100, PROP_NO_STR }, { '[', 0, 0, '.' } },
+      { "Tnom", PROP_REAL, { 26.85, PROP_NO_STR }, { '[', (-273), 0, '.' } },
+      { "Temp", PROP_REAL, { 26.85, PROP_NO_STR }, PROP_MIN_VAL (K) },
+      PROP_NO_PROP },
+    { PROP_NO_PROP }
+  },
+  /* MESFET verilog device */
+  { "MESFET", 3, PROP_COMPONENT, PROP_NO_SUBSTRATE, PROP_NONLINEAR,
+    {
+      { "LEVEL", PROP_INT, { 1, PROP_NO_STR }, { '[', 1, 5, ']' } },
+      { "Vto", PROP_REAL, { -1.8, PROP_NO_STR }, { '.', 0, 0, '.' } },
+      { "Beta", PROP_REAL, { 3e-3, PROP_NO_STR }, { '[', 1e-9, 0, '.' } },
+      { "Alpha", PROP_REAL, { 2.25, PROP_NO_STR }, { '[', 1e-9, 0, '.' } },
+      { "Lambda", PROP_REAL, { 0.05, PROP_NO_STR }, { '[', 1e-9, 0, '.' } },
+      { "B", PROP_REAL, { 0.3, PROP_NO_STR }, { '[', 1e-9, 0, '.' } },
+      { "Qp", PROP_REAL, { 2.1, PROP_NO_STR }, { '[', 1e-9, 0, '.' } },
+      { "Delta", PROP_REAL, { 0.1, PROP_NO_STR }, { '[', 1e-9, 0, '.' } },
+      { "Vmax", PROP_REAL, { 0.5, PROP_NO_STR }, { '[', 1e-9, 0, '.' } },
+      { "Vdelta1", PROP_REAL, { 0.3, PROP_NO_STR }, { '[', 1e-9, 0, '.' } },
+      { "Vdelta2", PROP_REAL, { 0.2, PROP_NO_STR }, { '[', 1e-9, 0, '.' } },
+      { "Gamma", PROP_REAL, { 0.015, PROP_NO_STR }, { '[', 1e-9, 0, '.' } },
+      { "Nsc", PROP_REAL, { 1, PROP_NO_STR }, { '[', 1e-9, 0, '.' } },
+      { "Is", PROP_REAL, { 1e-14, PROP_NO_STR }, { '[', 1e-20, 0, '.' } },
+      { "N", PROP_REAL, { 1, PROP_NO_STR }, { '[', 1e-9, 0, '.' } },
+      { "Vbi", PROP_REAL, { 1.0, PROP_NO_STR }, { '[', 1e-9, 0, '.' } },
+      { "Bv", PROP_REAL, { 60, PROP_NO_STR }, { '.', 0, 0, '.' } },
+      { "Xti", PROP_REAL, { 3.0, PROP_NO_STR }, { '[', 1e-9, 0, '.' } },
+      { "Fc", PROP_REAL, { 0.5, PROP_NO_STR }, { '[', 1e-6, 0, '.' } },
+      { "Tau", PROP_REAL, { 1e-9, PROP_NO_STR }, { '[', 1e-20, 0, '.' } },
+      { "Rin", PROP_REAL, { 1e-3, PROP_NO_STR }, { '[', 1e-20, 0, '.' } },
+      { "Area", PROP_REAL, { 1, PROP_NO_STR }, { '[', 1, 0, '.' } },
+      { "Eg", PROP_REAL, { 1.11, PROP_NO_STR }, { '[', 1e-6, 0, '.' } },
+      { "M", PROP_REAL, { 0.5, PROP_NO_STR }, { '[', 1e-9, 0, '.' } },
+      { "Cgd", PROP_REAL, { 0.2e-12, PROP_NO_STR }, { '[', 0, 0, '.' } },
+      { "Cgs", PROP_REAL, { 1e-12, PROP_NO_STR }, { '[', 0, 0, '.' } },
+      { "Cds", PROP_REAL, { 1e-12, PROP_NO_STR }, { '[', 0, 0, '.' } },
+      { "Betatc", PROP_REAL, { 0, PROP_NO_STR }, { '.', 0, 0, '.' } },
+      { "Alphatc", PROP_REAL, { 0, PROP_NO_STR }, { '.', 0, 0, '.' } },
+      { "Gammatc", PROP_REAL, { 0, PROP_NO_STR }, { '.', 0, 0, '.' } },
+      { "Ng", PROP_REAL, { 2.65, PROP_NO_STR }, { '[', 1, 0, '.' } },
+      { "Nd", PROP_REAL, { -0.19, PROP_NO_STR }, { '.', 0, 0, '.' } },
+      { "ILEVELS", PROP_INT, { 3, PROP_NO_STR }, { '[', 0, 4, ']' } },
+      { "ILEVELD", PROP_INT, { 3, PROP_NO_STR }, { '[', 0, 4, ']' } },
+      { "QLEVELS", PROP_INT, { 2, PROP_NO_STR }, { '[', 0, 3, ']' } },
+      { "QLEVELD", PROP_INT, { 2, PROP_NO_STR }, { '[', 0, 3, ']' } },
+      { "QLEVELDS", PROP_INT, { 2, PROP_NO_STR }, { '[', 0, 3, ']' } },
+      { "Vtotc", PROP_REAL, { 0, PROP_NO_STR }, { '.', 0, 0, '.' } },
+      { "Rg", PROP_REAL, { 5.1, PROP_NO_STR }, { '[', 1e-9, 0, '.' } },
+      { "Rd", PROP_REAL, { 1.3, PROP_NO_STR }, { '[', 1e-9, 0, '.' } },
+      { "Rs", PROP_REAL, { 1.3, PROP_NO_STR }, { '[', 1e-9, 0, '.' } },
+      { "Rgtc", PROP_REAL, { 0, PROP_NO_STR }, { '.', 0, 0, '.' } },
+      { "Rdtc", PROP_REAL, { 0, PROP_NO_STR }, { '.', 0, 0, '.' } },
+      { "Rstc", PROP_REAL, { 0, PROP_NO_STR }, { '.', 0, 0, '.' } },
+      { "Ibv", PROP_REAL, { 1e-3, PROP_NO_STR }, { '[', 1e-25, 0, '.' } },
+      { "Rf", PROP_REAL, { 10, PROP_NO_STR }, { '[', 1e-9, 0, '.' } },
+      { "R1", PROP_REAL, { 10, PROP_NO_STR }, { '[', 1e-9, 0, '.' } },
+      { "Af", PROP_REAL, { 1, PROP_NO_STR }, { '[', 0, 0, '.' } },
+      { "Kf", PROP_REAL, { 0, PROP_NO_STR }, { '[', 0, 0, '.' } },
+      { "Gdsnoi", PROP_REAL, { 1, PROP_NO_STR }, { '[', 0, 0, '.' } },
+      { "Tnom", PROP_REAL, { 26.85, PROP_NO_STR }, { '[', -273, 0, '.' } },
+      { "Temp", PROP_REAL, { 26.85, PROP_NO_STR }, PROP_MIN_VAL (K) },
+      PROP_NO_PROP },
+    { PROP_NO_PROP }
+  },
 
   /* microstrip substrate */
   { "SUBST", 0, PROP_COMPONENT, PROP_SUBSTRATE, PROP_LINEAR,
