@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: spsolver.h,v 1.14 2007/12/28 20:08:47 ela Exp $
+ * $Id: spsolver.h,v 1.15 2008/01/10 20:00:00 ela Exp $
  *
  */
 
@@ -28,7 +28,6 @@
 class analysis;
 class circuit;
 class node;
-class complex;
 class vector;
 class sweep;
 class nodelist;
@@ -56,7 +55,8 @@ class spsolver : public analysis
   void noiseConnect (circuit *, node *, node *);
   void noiseInterconnect (circuit *, node *, node *);
   void saveResults (nr_double_t);
-  void saveNoiseResults (complex[4], complex[4], nr_double_t, vector *);
+  void saveNoiseResults (nr_complex_t[4], nr_complex_t[4],
+			 nr_double_t, vector *);
   char * createSP (int, int);
   char * createCV (char *, char *);
   void saveCharacteristics (nr_double_t);
