@@ -1,7 +1,7 @@
 /*
  * tmatrix.h - simple matrix template class definitions
  *
- * Copyright (C) 2004, 2005 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2004, 2005, 2006 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,13 +18,15 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: tmatrix.h,v 1.12 2005/06/02 18:17:51 raimi Exp $
+ * $Id: tmatrix.h,v 1.14 2006/04/24 08:25:46 raimi Exp $
  *
  */
 
 #ifndef __TMATRIX_H__
 #define __TMATRIX_H__
 
+#include <assert.h>
+
 template <class nr_type_t>
 class tmatrix;
 
@@ -52,14 +54,19 @@ class tmatrix
   ~tmatrix ();
   nr_type_t get (int, int);
   void set (int, int, nr_type_t);
+  void set (nr_type_t);
   int  getCols (void) { return cols; }
   int  getRows (void) { return rows; }
   nr_type_t * getData (void) { return data; }
+  tvector<nr_type_t> getRow (int);
+  void setRow (int, tvector<nr_type_t>);
+  tvector<nr_type_t> getCol (int);
+  void setCol (int, tvector<nr_type_t>);
   void exchangeRows (int, int);
   void exchangeCols (int, int);
   void transpose (void);
   int  isFinite (void);
-  void print (void);
+  void print (bool realonly = false);
 
   // some basic matrix operations
 #ifndef _MSC_VER
@@ -70,9 +77,17 @@ class tmatrix
   friend tvector<nr_type_t> operator *<> (tvector<nr_type_t>, tmatrix);
 #endif
 
+  // intrinsic operators
+  tmatrix operator += (tmatrix);
+  tmatrix operator -= (tmatrix);
+
   // easy accessor operators
-  nr_type_t  operator () (int r, int c) const { return data[r * cols + c]; }
-  nr_type_t& operator () (int r, int c) { return data[r * cols + c]; }
+  nr_type_t  operator () (int r, int c) const {
+    assert (r >= 0 && r < rows && c >= 0 && c < cols);
+    return data[r * cols + c]; }
+  nr_type_t& operator () (int r, int c) {
+    assert (r >= 0 && r < rows && c >= 0 && c < cols);
+    return data[r * cols + c]; }
 
  private:
   int cols;
