@@ -1444,6 +1444,8 @@ Component* getComponentFromName(QString& Line)
 	else if(cstr == "us") c = new Resistor(false);  // backward capatible
 	else if(cstr == "SFF") c = new RS_FlipFlop();
 	else if(cstr == "elais") c = new Relais();
+	else if(cstr == "FEDD") c = new RFedd();
+	else if(cstr == "FEDD2P") c = new RFedd2P();
 	break;
   case 'C' : if(cstr.isEmpty()) c = new Capacitor();
 	else if(cstr == "CCS") c = new CCCS();
@@ -1497,6 +1499,7 @@ Component* getComponentFromName(QString& Line)
         else if(cstr == "LIN") c = new TLine();
         else if(cstr == "LIN4P") c = new TLine_4Port();
         else if(cstr == "WIST") c = new TwistedPair();
+        else if(cstr == "riac") c = new Triac();
         break;
   case 's' : if(cstr == "Tr") c = new symTrafo();
         break;
@@ -1513,12 +1516,14 @@ Component* getComponentFromName(QString& Line)
         else if(cstr == "UBST") c = new Substrate();
         else if(cstr == "PICE") c = new SpiceFile();
         else if(cstr == "witch") c = new Switch();
+        else if(cstr == "CR") c = new Thyristor();
         break;
   case 'D' : if(cstr == "CBlock") c = new dcBlock();
 	else if(cstr == "CFeed") c = new dcFeed();
 	else if(cstr == "iode") c = new Diode();
 	else if(cstr == "igiSource") c = new Digi_Source();
 	else if(cstr == "FF") c = new D_FlipFlop();
+	else if(cstr == "iac") c = new Diac();
 	break;
   case 'B' : if(cstr == "iasT") c = new BiasT();
         else if(cstr == "JT") c = new BJTsub();
@@ -1542,6 +1547,7 @@ Component* getComponentFromName(QString& Line)
 	else if(cstr == "GAP") c = new MSgap();
 	else if(cstr == "COUPLED") c = new MScoupled();
 	else if(cstr == "VIA") c = new MSvia();
+	else if(cstr == "ESFET") c = new MESFET();
 	break;
   case 'E' : if(cstr == "qn") c = new Equation();
 	else if(cstr == "DD") c = new EqnDefined();
@@ -1569,11 +1575,16 @@ Component* getComponentFromName(QString& Line)
         break;
   case 'h' : if(cstr == "icumL2p1") c = new hicumL2p1();
         else if(cstr == "ic2_full") c = new hic2_full();
+        else if(cstr == "ic0_full") c = new hic0_full();
         break;
   case 'H' : if(cstr == "BT_X") c = new HBT_X();
         break;
   case 'm' : if(cstr == "od_amp") c = new mod_amp();
         break;
+  case 'l' : if(cstr == "og_amp") c = new log_amp();
+        break;
+  case 'p' : if(cstr == "otentiometer") c = new potentiometer();
+        break;
   }
   if(!c) {
     QMessageBox::critical(0, QObject::tr("Error"),
