@@ -1,6 +1,6 @@
 /***************************************************************************
-                           jfet.h  -  description
-                             -------------------
+                                  jfet.h
+                                 --------
     begin                : Fri Jun 4 2004
     copyright            : (C) 2003 by Michael Margraf
     email                : michael.margraf@alumni.tu-berlin.de
@@ -21,14 +21,16 @@
 #include "component.h"
 
 
-class JFET : public Component  {
+class JFET : public MultiViewComponent {
 public:
   JFET();
-  ~JFET();
+ ~JFET() {};
   Component* newOne();
   static Element* info(QString&, char* &, bool getNewOne=false);
   static Element* info_p(QString&, char* &, bool getNewOne=false);
-  void recreate();
+
+protected:
+  void createSymbol();
 };
 
 #endif
