@@ -36,6 +36,7 @@ extern QDir QucsWorkDir;
 
 LibComp::LibComp()
 {
+  Type = isComponent;   // both analog and digital
   Description = QObject::tr("Component taken from Qucs library");
 
   Ports.append(new Port(0,  0));  // dummy port because of being device
@@ -87,9 +88,11 @@ void LibComp::createSymbol()
 
 // ---------------------------------------------------------------------
 // Loads the section with name "Name" from library file into "Section".
-int LibComp::loadSection(const QString& Name, QString& Section)
+int LibComp::loadSection(const QString& Name, QString& Section,
+			 QStringList *Includes)
 {
-  QFile file(QucsSettings.LibDir + Props.first()->Value + ".lib");
+  QDir Directory(QucsSettings.LibDir);
+  QFile file(Directory.absFilePath(Props.first()->Value + ".lib"));
   if(!file.open(IO_ReadOnly))
     return -1;
 
@@ -101,14 +104,12 @@ int LibComp::loadSection(const QString& Name, QString& Section)
   if(Section.left(14) != "<Qucs Library ")  // wrong file type ?
     return -2;
 
-  QString s = PACKAGE_VERSION;
-  s.remove('.');
-  QString Line = Section.mid(14, 5);
-  Line.remove('.');
-  if(Line > s)   // wrong version number ? (only backward compatible)
+  int Start, End = Section.find(' ', 14);
+  if(End < 15) return -3;
+  QString Line = Section.mid(14, End-14);
+  if(!checkVersion(Line)) // wrong version number ?
     return -3;
 
-  int Start, End;
   if(Name == "Symbol") {
     Start = Section.find("\n<", 14); // if library has default symbol, take it
     if(Start > 0)
@@ -132,6 +133,24 @@ int LibComp::loadSection(const QString& Name, QString& Section)
   if(End < 0)  return -6;  // file corrupt
   Section = Section.mid(Start, End-Start+1);
   
+  // search model includes
+  if(Includes) {
+    int StartI, EndI;
+    StartI = Section.find("<"+Name+"Includes");
+    if(StartI >= 0) {  // includes found
+      StartI = Section.find('"', StartI);
+      if(StartI < 0)  return -10;  // file corrupt
+      EndI = Section.find('>', StartI);
+      if(EndI < 0)  return -11;  // file corrupt
+      StartI++; EndI--;
+      QString inc = Section.mid(StartI, EndI-StartI);
+      QStringList f = QStringList::split(QRegExp("\"\\s+\""), inc);
+      for(QStringList::Iterator it = f.begin(); it != f.end(); ++it ) {
+	Includes->append(*it);
+      }
+    }
+  }
+
   // search model
   Start = Section.find("<"+Name+">");
   if(Start < 0)  return -7;  // symbol not found
@@ -140,6 +159,8 @@ int LibComp::loadSection(const QString& Name, QString& Section)
   while(Section.at(++Start) == ' ') ;
   End = Section.find("</"+Name+">", Start);
   if(End < 0)  return -9;  // file corrupt
+
+  // snip actual model
   Section = Section.mid(Start, End-Start);
   return 0;
 }
@@ -152,7 +173,31 @@ int LibComp::loadSymbol()
   int z, Result;
   QString FileString, Line;
   z = loadSection("Symbol", FileString);
-  if(z < 0)  return z;
+  if(z < 0) {
+    if(z != -7)  return z;
+
+    // If library component not defined as subcircuit, then load
+    // new component and transfer data to this component.
+    z = loadSection("Model", Line);
+    if(z < 0)  return z;
+
+    Component *pc = getComponentFromName(Line);
+    if(pc == 0)  return -20;
+
+    copyComponent(pc);
+
+    pc->Arcs.setAutoDelete(false);
+    pc->Lines.setAutoDelete(false);
+    pc->Rects.setAutoDelete(false);
+    pc->Ellips.setAutoDelete(false);
+    pc->Ports.setAutoDelete(false);
+    pc->Texts.setAutoDelete(false);
+    pc->Props.setAutoDelete(false);
+    delete pc;
+
+    return 1;
+  }
+
 
   z  = 0;
   x1 = y1 = INT_MAX;
@@ -166,7 +211,7 @@ int LibComp::loadSymbol()
     if(Line.at(0) != '<') return -11;
     if(Line.at(Line.length()-1) != '>') return -12;
     Line = Line.mid(1, Line.length()-2); // cut off start and end character
-    Result = analyseLine(Line);
+    Result = analyseLine(Line, 2);
     if(Result < 0) return -13;   // line format error
     z += Result;
   }
@@ -177,18 +222,61 @@ int LibComp::loadSymbol()
 }
 
 // -------------------------------------------------------
-bool LibComp::outputSubNetlist(QTextStream *stream)
+QString LibComp::getSubcircuitFile()
 {
-  int r;
-  QString FileString;
-  r = loadSection("Model", FileString);
-  if(r < 0)  return false;
-  (*stream) << "\n" << FileString << "\n";
-  return true;
+  QDir Directory(QucsSettings.LibDir);
+  QString FileName = Directory.absFilePath(Props.first()->Value);
+  return properAbsFileName(FileName);
 }
 
 // -------------------------------------------------------
-QString LibComp::NetList()
+bool LibComp::createSubNetlist(QTextStream *stream, QStringList &FileList,
+			       int type)
+{
+  int r = -1;
+  QString FileString;
+  QStringList Includes;
+  if(type&1) {
+    r = loadSection("Model", FileString, &Includes);
+  } else if(type&2) {
+    r = loadSection("VHDLModel", FileString, &Includes);
+  } else if(type&4) {
+    r = loadSection("VerilogModel", FileString, &Includes);
+  }
+  if(r < 0)  return false;
+
+  // also include files
+  int error = 0;
+  for(QStringList::Iterator it = Includes.begin();
+      it != Includes.end(); ++it ) {
+    QString s = getSubcircuitFile()+"/"+*it;
+    if(FileList.findIndex(s) >= 0) continue;
+    FileList.append(s);
+
+    // load file and stuff into stream
+    QFile file(s);
+    if(!file.open(IO_ReadOnly)) {
+      error++;
+    } else {
+      QByteArray FileContent = file.readAll();
+      file.close();
+      stream->writeRawBytes(FileContent.data(), FileContent.size());
+    }
+  }
+
+  (*stream) << "\n" << FileString << "\n";
+  return error > 0 ? false : true;
+}
+
+// -------------------------------------------------------
+QString LibComp::createType()
+{
+  QString Type = properFileName(Props.first()->Value);
+  return properName(Type + "_" + Props.next()->Value);
+}
+
+// -------------------------------------------------------
+QString LibComp::netlist()
 {
   QString s = "Sub:"+Name;   // output as subcircuit
 
@@ -197,10 +285,41 @@ QString LibComp::NetList()
     s += " "+p1->Connection->Name;   // node names
 
   // output property
-  QString Type = Props.first()->Value;
-  Type += "_" + Props.next()->Value;
-  Type.replace(QRegExp("\\W"), "_");
-  s += " Type=\""+Type+"\"";   // type for subcircuit
+  s += " Type=\""+createType()+"\"";   // type for subcircuit
 
+  // output user defined parameters
+  for(Property *pp = Props.at(2); pp != 0; pp = Props.next())
+    s += " "+pp->Name+"=\""+pp->Value+"\"";
+
+  return s + '\n';
+}
+
+// -------------------------------------------------------
+QString LibComp::verilogCode(int)
+{
+  QString s = "  Sub_" + createType() + " " + Name + " (";
+
+  // output all node names
+  Port *pp = Ports.first();
+  if(pp)  s += pp->Connection->Name;
+  for(pp = Ports.next(); pp != 0; pp = Ports.next())
+    s += ", "+pp->Connection->Name;   // node names
+
+  s += ");\n";
+  return s;
+}
+
+// -------------------------------------------------------
+QString LibComp::vhdlCode(int)
+{
+  QString s = "  " + Name + ": entity Sub_" + createType() + " port map (";
+
+  // output all node names
+  Port *pp = Ports.first();
+  if(pp)  s += pp->Connection->Name;
+  for(pp = Ports.next(); pp != 0; pp = Ports.next())
+    s += ", "+pp->Connection->Name;   // node names
+
+  s += ");\n";
   return s;
 }
