@@ -1,6 +1,6 @@
 /***************************************************************************
-                          resistor.h  -  description
-                             -------------------
+                                resistor.h
+                               ------------
     begin                : Sat Aug 23 2003
     copyright            : (C) 2003 by Michael Margraf
     email                : michael.margraf@alumni.tu-berlin.de
@@ -21,17 +21,16 @@
 #include "component.h"
 
 
-class Resistor : public Component  {
+class Resistor : public MultiViewComponent  {
 public:
   Resistor(bool european=true);
-  ~Resistor();
+ ~Resistor() {};
   Component* newOne();
   static Element* info(QString&, char* &, bool getNewOne=false);
   static Element* info_us(QString&, char* &, bool getNewOne=false);
-  void recreate();
 
-private:
-  void createSymbol(bool european=true);
+protected:
+  void createSymbol();
 };
 
 #endif
