@@ -33,6 +33,7 @@
 #include <qcheckbox.h>
 #include <qprocess.h>
 #include <qmessagebox.h>
+#include <qcombobox.h>
 
 
 SpiceDialog::SpiceDialog(SpiceFile *c, Schematic *d)
@@ -82,6 +83,17 @@ SpiceDialog::SpiceDialog(SpiceFile *c, Schematic *d)
   SimCheck = new QCheckBox(tr("include SPICE simulations"), myParent);
   topGrid->addWidget(SimCheck, 3,1);
 
+  QHBox *h1 = new QHBox(myParent);
+  h1->setSpacing(5);
+  PrepCombo = new QComboBox(h1);
+  PrepCombo->insertItem("none");
+  PrepCombo->insertItem("ps2sp");
+  PrepCombo->insertItem("spicepp");
+  PrepCombo->insertItem("spiceprm");
+  QLabel * PrepLabel = new QLabel(tr("preprocessor"), h1);
+  PrepLabel->setMargin(5);
+  topGrid->addWidget(h1, 4,1);
+  connect(PrepCombo, SIGNAL(activated(int)), SLOT(slotPrepChanged(int)));
 
   // ...........................................................
   QGridLayout *midGrid = new QGridLayout(0, 2,3,5,5);
@@ -129,6 +141,13 @@ SpiceDialog::SpiceDialog(SpiceFile *c, Schematic *d)
   FileEdit->setText(pp->Value);
   FileCheck->setChecked(pp->display);
   SimCheck->setChecked(Comp->Props.at(2)->Value == "yes");
+  for(int i=0; i<PrepCombo->count(); i++) {
+    if(PrepCombo->text(i) == Comp->Props.at(3)->Value) {
+      PrepCombo->setCurrentItem(i);
+      currentPrep = i;
+      break;
+    }
+  }
 
   loadSpiceNetList(pp->Value);  // load netlist nodes
 }
@@ -211,13 +230,18 @@ void SpiceDialog::slotButtApply()
   }
   if(pp->Value != "yes")  Comp->withSim = false;
 
+  pp = Comp->Props.next();
+  if(pp->Value != PrepCombo->currentText()) {
+    pp->Value = PrepCombo->currentText();
+    changed = true;
+  }
+
   if(changed || Comp->withSim) {  // because of "sim" text
     Doc->recreateComponent(Comp); // to apply changes to the schematic symbol
     Doc->viewport()->repaint();
   }
 }
 
-static QString lastDir;  // to remember last directory and file
 // -------------------------------------------------------------------------
 void SpiceDialog::slotButtBrowse()
 {
@@ -227,18 +251,28 @@ void SpiceDialog::slotButtBrowse()
 		this, "", tr("Select a file"));
   if(s.isEmpty()) return;
 
-  lastDir = s;   // remember last directory and file
+  QFileInfo Info(s);
+  lastDir = Info.dirPath(true);  // remember last directory
 
   // snip path if file in current directory
-  QFileInfo FileInfo(s);
-  if(QucsWorkDir.exists(FileInfo.fileName()) &&
-     QucsWorkDir.absPath() == FileInfo.dirPath(true)) s = FileInfo.fileName();
+  if(QucsWorkDir.exists(Info.fileName()) &&
+     QucsWorkDir.absPath() == Info.dirPath(true)) s = Info.fileName();
   FileEdit->setText(s);
 
   Comp->Props.at(1)->Value = "";
   loadSpiceNetList(s);
 }
 
+// -------------------------------------------------------------------------
+void SpiceDialog::slotPrepChanged(int i)
+{
+  if(currentPrep != i) {
+    currentPrep = i;
+    PrepCombo->setCurrentItem(i);
+    loadSpiceNetList(FileEdit->text());  // reload netlist nodes
+  }
+}
+
 // -------------------------------------------------------------------------
 bool SpiceDialog::loadSpiceNetList(const QString& s)
 {
@@ -251,6 +285,84 @@ bool SpiceDialog::loadSpiceNetList(const QString& s)
   textStatus = 0;
   Line = Error = "";
 
+  QString preprocessor = PrepCombo->currentText();
+  if (preprocessor != "none") {
+    bool piping = true;
+    QString script;
+#ifdef __MINGW32__
+    QString interpreter = "tinyperl.exe";
+#else
+    QString interpreter = "perl";
+#endif
+    if (preprocessor == "ps2sp") {
+      script = "ps2sp.pl";
+    } else if (preprocessor == "spicepp") {
+      script = "spicepp.pl";
+    } else if (preprocessor == "spiceprm") {
+      script = "spiceprm";
+      piping = false;
+    }
+    script = QucsSettings.BinDir + script;
+    SpicePrep = new QProcess(this);
+    SpicePrep->addArgument(interpreter);
+    SpicePrep->addArgument(script);
+    SpicePrep->addArgument(FileInfo.filePath());
+
+    QFile PrepFile;
+    QFileInfo PrepInfo(QucsWorkDir, s + ".pre");
+    QString PrepName = PrepInfo.filePath();
+
+    if (!piping) {
+      SpicePrep->addArgument(PrepName);
+      connect(SpicePrep, SIGNAL(readyReadStdout()), SLOT(slotSkipOut()));
+      connect(SpicePrep, SIGNAL(readyReadStderr()), SLOT(slotGetPrepErr()));
+    } else {
+      connect(SpicePrep, SIGNAL(readyReadStdout()), SLOT(slotGetPrepOut()));
+      connect(SpicePrep, SIGNAL(readyReadStderr()), SLOT(slotGetPrepErr()));
+    }
+
+    QMessageBox *MBox = new QMessageBox(tr("Info"),
+	       tr("Preprocessing SPICE file \"%1\".").arg(FileInfo.filePath()),
+               QMessageBox::NoIcon, QMessageBox::Abort,
+               QMessageBox::NoButton, QMessageBox::NoButton, this, 0, true,
+	       Qt::WStyle_DialogBorder |  Qt::WDestructiveClose);
+    connect(SpicePrep, SIGNAL(processExited()), MBox, SLOT(close()));
+
+    if (piping) {
+      PrepFile.setName(PrepName);
+      if(!PrepFile.open(IO_WriteOnly)) {
+	QMessageBox::critical(this, tr("Error"),
+          tr("Cannot save preprocessed SPICE file \"%1\".").
+	  arg(PrepName));
+	return false;
+      }
+      prestream = new QTextStream(&PrepFile);
+    }
+
+    if(!SpicePrep->start()) {
+      QMessageBox::critical(this, tr("Error"),
+        tr("Cannot execute \"%1\".").arg(interpreter + " " + script));
+      if (piping) {
+	PrepFile.close();
+	delete prestream;
+      }
+      return false;
+    }
+    SpicePrep->closeStdin();
+
+    MBox->exec();
+    delete SpicePrep;
+    if (piping) {
+      PrepFile.close();
+      delete prestream;
+    }
+
+    if(!Error.isEmpty()) {
+      QMessageBox::critical(this, tr("SPICE Preprocessor Error"), Error);
+      return false;
+    }
+    FileInfo = QFileInfo(QucsWorkDir, s + ".pre");
+  }
 
   // first call Qucsconv ............
   QucsConv = new QProcess(this);
@@ -264,7 +376,8 @@ bool SpiceDialog::loadSpiceNetList(const QString& s)
   connect(QucsConv, SIGNAL(readyReadStdout()), SLOT(slotGetNetlist()));
   connect(QucsConv, SIGNAL(readyReadStderr()), SLOT(slotGetError()));
 
-  QMessageBox *MBox = new QMessageBox(tr("Info"), tr("Converting ..."),
+  QMessageBox *MBox = new QMessageBox(tr("Info"),
+	       tr("Converting SPICE file \"%1\".").arg(FileInfo.filePath()),
                QMessageBox::NoIcon, QMessageBox::Abort,
                QMessageBox::NoButton, QMessageBox::NoButton, this, 0, true,
 	       Qt::WStyle_DialogBorder |  Qt::WDestructiveClose);
@@ -272,7 +385,7 @@ bool SpiceDialog::loadSpiceNetList(const QString& s)
 
   if(!QucsConv->start()) {
     QMessageBox::critical(this, tr("Error"),
-                 tr("Cannot execute")+" "+QucsSettings.BinDir + "qucsconv.");
+      tr("Cannot execute \"%1\".").arg(QucsSettings.BinDir + "qucsconv"));
     return false;
   }
   QucsConv->closeStdin();
@@ -302,6 +415,30 @@ bool SpiceDialog::loadSpiceNetList(const QString& s)
   return true;
 }
 
+// -------------------------------------------------------------------------
+void SpiceDialog::slotSkipErr()
+{
+  SpicePrep->readStderr();
+}
+
+// -------------------------------------------------------------------------
+void SpiceDialog::slotSkipOut()
+{
+  SpicePrep->readStdout();
+}
+
+// -------------------------------------------------------------------------
+void SpiceDialog::slotGetPrepErr()
+{
+  Error += QString(SpicePrep->readStderr());
+}
+
+// -------------------------------------------------------------------------
+void SpiceDialog::slotGetPrepOut()
+{
+  (*prestream) << QString(SpicePrep->readStdout());
+}
+
 // -------------------------------------------------------------------------
 void SpiceDialog::slotGetError()
 {
