@@ -46,7 +46,7 @@ Subcircuit::Subcircuit()
   Name  = "SUB";
 
   // Do NOT call createSymbol() here. But create port to let it rotate.
-  Ports.append(new Port(0, 0));
+  Ports.append(new Port(0, 0, false));
 }
 
 // ---------------------------------------------------------------------
@@ -62,7 +62,7 @@ Component* Subcircuit::newOne()
 Element* Subcircuit::info(QString& Name, char* &BitmapFile, bool getNewOne)
 {
   Name = QObject::tr("Subcircuit");
-  BitmapFile = "subcircuit";
+  BitmapFile = (char *) "subcircuit";
 
   if(getNewOne) {
     Subcircuit *p = new Subcircuit();
@@ -86,6 +86,9 @@ void Subcircuit::createSymbol()
   if(loadSymbol(FileName) > 0) {  // try to load subcircuit symbol
     if(tx == INT_MIN)  tx = x1+4;
     if(ty == INT_MIN)  ty = y2+4;
+    // remove unused ports
+    for(Port *pp = Ports.first(); pp != 0; pp = Ports.next())
+      if(!pp->avail) Ports.remove();
   }
   else {
     No = QucsApp::testFile(FileName);
