@@ -27,13 +27,18 @@ public:
  ~VHDL_File() {};
   Component* newOne();
   static Element* info(QString&, char* &, bool getNewOne=false);
-  QString VHDL_Code(int);
+
+  bool createSubNetlist(QTextStream *);
+  QString getErrorText() { return ErrText; }
+  QString getSubcircuitFile();
 
 protected:
+  QString vhdlCode(int);
   void createSymbol();
   QString loadFile();
 
   QString EntityName;
+  QString ErrText;
 };
 
 #endif
