@@ -302,10 +302,16 @@ void Diagram::createAxisLabels()
 int Diagram::regionCode(float x, float y)
 {
   int code=0;   // code for clipping
-  if(x < 0.0)  code |= 1;
-  else if(int(x) > x2)  code |= 2;
-  if(y < 0.0)  code |= 4;
-  else if(int(y) > y2)  code |= 8;
+  if(x < 0.0)
+    code |= 1;
+  else if(x > float(x2))  // compare as float to avoid integer overflow
+    code |= 2;
+
+  if(y < 0.0)
+    code |= 4;
+  else if(y > float(y2))  // compare as float to avoid integer overflow
+    code |= 8;
+
   return code;
 }
 
@@ -685,10 +691,10 @@ void Diagram::getAxisLimits(Graph *pg)
   }
 
   if(Name == "Rect3D") {
-    pD = pg->cPointsX.next();
-    if(pD) {
-      p = pD->Points;
-      for(z=pD->count; z>0; z--) { // check y coordinates (2. dimension)
+    DataX *pDy = pg->cPointsX.next();
+    if(pDy) {
+      p = pDy->Points;
+      for(z=pDy->count; z>0; z--) { // check y coordinates (2. dimension)
 	y = *(p++);
 	if(finite(y)) {
 	  if(y > yAxis.max) yAxis.max = y;
@@ -703,6 +709,7 @@ void Diagram::getAxisLimits(Graph *pg)
   else  pa = &zAxis;
   (pa->numGraphs)++;    // count graphs
   p = pg->cPointsY;
+  if(p == 0) return;    // if no data => invalid
   for(z=pg->countY*pD->count; z>0; z--) {  // check every y coordinate
     x = *(p++);
     y = *(p++);
