@@ -171,30 +171,21 @@ void MouseActions::editLabel(Schematic *Doc, WireLabel *pl)
 void MouseActions::endElementMoving(Schematic *Doc, QPtrList<Element> *movElements)
 {
   Element *pe;
-
-  // First the wires with length zero are removed. This is important
-  // if they are labeled. These labels must be put in the schematic
-  // before all other elements.
-  for(pe = movElements->first(); pe != 0; ) {
-    if(pe->Type == isWire)
-      if(pe->x1 == pe->x2) if(pe->y1 == pe->y2) {
-	if(((Wire*)pe)->Label) {
-	  Doc->insertNodeLabel((WireLabel*)((Wire*)pe)->Label);
-	  ((Wire*)pe)->Label = 0;
-	}
-	movElements->removeRef(pe);
-	delete (Wire*)pe;
-	pe = movElements->current();
-	continue;
-      }
-    pe = movElements->next();
-  }
-
-
   for(pe = movElements->first(); pe!=0; pe = movElements->next()) {
 //    pe->isSelected = false;  // deselect first (maybe afterwards pe == NULL)
     switch(pe->Type) {
       case isWire:
+        if(pe->x1 == pe->x2)
+          if(pe->y1 == pe->y2) {
+            // Delete wires with zero length, but preserve label.
+            if(((Wire*)pe)->Label) {
+              Doc->insertNodeLabel((WireLabel*)((Wire*)pe)->Label);
+              ((Wire*)pe)->Label = 0;
+            }
+            delete (Wire*)pe;
+            break;
+          }
+
 	Doc->insertWire((Wire*)pe);
 	break;
       case isDiagram:
@@ -375,11 +366,12 @@ void MouseActions::MMoveSelect(Schematic *Doc, QMouseEvent *Event)
   drawn = true;
   MAx2 = DOC_X_POS(Event->pos().x()) - MAx1;
   MAy2 = DOC_Y_POS(Event->pos().y()) - MAy1;
-  if(isMoveEqual)     // x and y size must be equal ?
+  if(isMoveEqual) {    // x and y size must be equal ?
     if(abs(MAx2) > abs(MAy2)) {
       if(MAx2<0) MAx2 = -abs(MAy2); else MAx2 = abs(MAy2);
     }
     else { if(MAy2<0) MAy2 = -abs(MAx2); else MAy2 = abs(MAx2); }
+  }
   painter.drawRect(MAx1, MAy1, MAx2, MAy2); // paint new rectangle
 }
 
@@ -1872,7 +1864,7 @@ void MouseActions::editElement(Schematic *Doc, QMouseEvent *Event)
 
     case isDiagram :
          dia = (Diagram*)focusElement;
-         if(dia->Name.at(0) == 'T')  // don't open dialog on scrollbar
+         if(dia->Name.at(0) == 'T') { // don't open dialog on scrollbar
            if(dia->Name == "Time") {
              if(dia->cy < int(fY)) {
 	       if(((TimingDiagram*)focusElement)->scroll(MAx1))
@@ -1887,6 +1879,7 @@ void MouseActions::editElement(Schematic *Doc, QMouseEvent *Event)
 	       break;
              }
 	   }
+	 }
 
 	 ddia = new DiagramDialog(dia,
 		Info.dirPath() + QDir::separator() + Doc->DataSet, Doc);
