@@ -26,7 +26,7 @@
 class Ellipse : public Painting  {
 public:
   Ellipse(bool _filled=false);
-  ~Ellipse();
+ ~Ellipse();
 
   void paintScheme(QPainter*);
   void getCenter(int&, int&);
@@ -40,9 +40,8 @@ public:
   void paint(ViewPainter*);
   void MouseMoving(QPainter*, int, int, int, int, QPainter*, int, int, bool);
   bool MousePressing();
-  bool getSelected(int, int);
-  void Bounding(int&, int&, int&, int&);
-  bool ResizeTouched(int, int);
+  bool getSelected(float, float, float);
+  bool resizeTouched(float, float, float);
   void MouseResizeMoving(int, int, QPainter*);
 
   void rotate();
