@@ -147,6 +147,7 @@ QucsApp::QucsApp()
 #if defined (QT_VERSION) && QT_VERSION > 0x030200
   Printer->setOptionEnabled(QPrinter::PrintSelection, true);
   Printer->setOptionEnabled(QPrinter::PrintPageRange, false);
+  Printer->setOptionEnabled(QPrinter::PrintToFile, true);
 #endif
   Printer->setColorMode(QPrinter::Color);
   Printer->setFullPage(true);
@@ -315,7 +316,7 @@ pInfoFunc lumpedComponents[] =
    &Amplifier::info, &Isolator::info, &Circulator::info,
    &Gyrator::info, &Phaseshifter::info, &Coupler::info, &iProbe::info,
    &vProbe::info, &Mutual::info, &Mutual2::info, &Switch::info,
-   &Relais::info, 0};
+   &Relais::info, &RFedd::info, &RFedd2P::info, 0};
 
 pInfoFunc Sources[] =
   {&Volt_dc::info, &Ampere_dc::info, &Volt_ac::info, &Ampere_ac::info,
@@ -340,8 +341,14 @@ pInfoFunc nonlinearComps[] =
    &BJTsub::info_pnp, &JFET::info, &JFET::info_p,
    &MOSFET::info, &MOSFET::info_p, &MOSFET::info_depl,
    &MOSFET_sub::info, &MOSFET_sub::info_p, &MOSFET_sub::info_depl,
-   &OpAmp::info, &hicumL2p1::info, &HBT_X::info, &EqnDefined::info,
-   &mod_amp::info, &hic2_full::info, 0};
+   &OpAmp::info, &EqnDefined::info, &Diac::info, &Triac::info,
+   &Thyristor::info,
+   0};
+
+pInfoFunc VerilogAComps[] =
+  {&hicumL2p1::info, &HBT_X::info, &mod_amp::info, &hic2_full::info,
+   &log_amp::info, &hic0_full::info, &hic0_full::info_pnp,
+   &potentiometer::info, &MESFET::info, 0};
 
 pInfoFunc digitalComps[] =
   {&Digi_Source::info, &Logical_Inv::info, &Logical_OR::info,
@@ -373,7 +380,7 @@ pInfoFunc Paintings[] =
 // Order of the component groups in the ComboBox
 pInfoFunc *ComponentGroups[] =
   {lumpedComponents, Sources, Probes, TransmissionLines, nonlinearComps,
-   digitalComps, FileComponents, Simulations, Diagrams, 0};
+   VerilogAComps, digitalComps, FileComponents, Simulations, Diagrams, 0};
 
 // ---------------------------------------------------------------
 // Put the component groups into the ComboBox. It is possible to
@@ -387,6 +394,7 @@ void QucsApp::fillComboBox(bool setAll)
     CompChoose->insertItem(tr("probes"));
     CompChoose->insertItem(tr("transmission lines"));
     CompChoose->insertItem(tr("nonlinear components"));
+    CompChoose->insertItem(tr("verilog-a devices"));
     CompChoose->insertItem(tr("digital components"));
     CompChoose->insertItem(tr("file components"));
     CompChoose->insertItem(tr("simulations"));
@@ -1536,10 +1544,12 @@ void QucsApp::printCurrentDocument(bool fitToPage)
   else
     Printer->setOrientation(QPrinter::Landscape);
 
+  //Printer->setPrintRange(QPrinter::AllPages);
+
   if(Printer->setup(this)) {   // printer dialog
 
     QPainter Painter(Printer);
-    if(!Painter.device())   // valid device available ?
+    if(!Painter.device())      // valid device available ?
       goto Error;
 
     for(int z=Printer->numCopies(); z>0 ; z--) {
