@@ -41,10 +41,12 @@ class QListView;
 class QListViewItem;
 class QIconView;
 class QIconViewItem;
+class VTabbedDockWidget;
+class VTabWidget;
 
 typedef bool (Schematic::*pToggleFunc) ();
 typedef void (MouseActions::*pMouseFunc) (Schematic*, QMouseEvent*);
-typedef void (MouseActions::*pMouseFunc2) (Schematic*, QMouseEvent*, int, int);
+typedef void (MouseActions::*pMouseFunc2) (Schematic*, QMouseEvent*, float, float);
 
 extern QDir QucsWorkDir;
 extern QDir QucsHomeDir;
@@ -68,7 +70,7 @@ public:
 
   // current mouse methods
   void (MouseActions::*MouseMoveAction) (Schematic*, QMouseEvent*);
-  void (MouseActions::*MousePressAction) (Schematic*, QMouseEvent*, int, int);
+  void (MouseActions::*MousePressAction) (Schematic*, QMouseEvent*, float, float);
   void (MouseActions::*MouseDoubleClickAction) (Schematic*, QMouseEvent*);
   void (MouseActions::*MouseReleaseAction) (Schematic*, QMouseEvent*);
 
@@ -83,10 +85,10 @@ public slots:
   void slotFileSaveAs();  // save a document under a different filename
   void slotFileSaveAll(); // save all open documents
   void slotFileClose();   // close the actual file
-  void slotSymbolEdit();   // edit the symbol for the schematic
+  void slotSymbolEdit();  // edit the symbol for the schematic
   void slotFileSettings();// open dialog to change file settings
   void slotFilePrint();   // print the current file
-  void slotFilePrintSelected();  // Print selected elements
+  void slotFilePrintFit();// Print and fit to page
   void slotFileQuit();    // exits the application
   void slotEditCut();     // put marked object into clipboard and delete it
   void slotEditCopy();    // put the marked object into the clipboard
@@ -118,6 +120,7 @@ private slots:
   void slotOpenProject(QListBoxItem*);
   void slotMenuCloseProject();
   void slotSelectSubcircuit(QListViewItem*);
+  void slotExpandContentList(QListViewItem*);
   void slotOpenContent(QListViewItem*);
   void slotSetCompView(int);
   void slotProjNewButt();
@@ -146,7 +149,7 @@ public:
   QAction *fileNew, *textNew, *fileNewDpl, *fileOpen, *fileSave, *fileSaveAs,
           *fileSaveAll, *fileClose, *fileSettings, *filePrint, *fileQuit,
           *projNew, *projOpen, *projDel, *projClose, *applSettings,
-          *editCut, *editCopy, *magAll, *magOne, *magMinus, *filePrintSel,
+          *editCut, *editCopy, *magAll, *magOne, *magMinus, *filePrintFit,
           *symEdit, *intoH, *popH, *simulate, *dpl_sch, *undo, *redo, *dcbias;
 
   QAction *activeAction;    // pointer to the action selected by the user
@@ -155,12 +158,13 @@ private:
   QPrinter  *Printer; // printer is global (to remember the user settings)
 
 // ********* Widgets on the main area **********************************
-  QTabWidget    *TabView;
+  VTabbedDockWidget   *dock;
+  VTabWidget    *TabView;
 
   QListBox      *Projects;
   QListView     *Content;
   QListViewItem *ConSchematics, *ConSources, *ConDisplays, *ConDatasets,
-                *ConOthers;
+                *ConOthers, *ConVerilog;
 
   QComboBox     *CompChoose;
 
@@ -173,17 +177,19 @@ private:
   void initCursorMenu();
   void initContentListView();
 
+  void printCurrentDocument(bool);
   bool saveFile(QucsDoc *Doc=0);
   bool saveAs();
   void readProjects();
   void readProjectFiles();
-  void OpenProject(const QString&, const QString&);
-  bool DeleteProject(const QString&, const QString&);
+  void openProject(const QString&, const QString&);
+  bool deleteProject(const QString&, const QString&);
   void updatePortNumber(QucsDoc*, int);
   void fillComboBox(bool);
   void switchSchematicDoc(bool);
   void switchEditMode(bool);
   void changeSchematicSymbolMode(Schematic*);
+  bool deleteDirectoryContent(QDir& Dir);
 
 
 
@@ -193,23 +199,26 @@ private:
    ************************************************** */
 
 public slots:
-  void slotViewToolBar(bool toggle);    // toggle the toolbar
-  void slotViewStatusBar(bool toggle);  // toggle the statusbar
-
-  void slotHelpAbout();       // shows an about dialog
-  void slotHelpAboutQt();     // shows the standard about dialog for Qt
-
   void slotShowWarnings();
   void slotResetWarnings();
   void printCursorPosition(int, int);
 
+private slots:
+  void slotViewToolBar(bool toggle);    // toggle the toolbar
+  void slotViewStatusBar(bool toggle);  // toggle the statusbar
+  void slotViewBrowseDock(bool toggle); // toggle the dock window
+  void slotToggleDock(bool);
+  void slotHelpAbout();     // shows an about dialog
+  void slotHelpAboutQt();   // shows the standard about dialog for Qt
+
 private:
   void initActions();    // initializes all QActions of the application
   void initMenuBar();    // creates the menu_bar and inserts the menuitems
   void initToolBar();    // creates the toolbars
   void initStatusBar();  // setup the statusbar
 
-  QAction *helpAboutApp, *helpAboutQt, *viewToolBar, *viewStatusBar;
+  QAction *helpAboutApp, *helpAboutQt, *viewToolBar, *viewStatusBar,
+          *viewBrowseDock;
 
   // menus contain the items of their menubar
   QPopupMenu *fileMenu, *editMenu, *insMenu, *projMenu, *simMenu, *viewMenu,
@@ -236,7 +245,9 @@ public:
           *helpIndex, *helpGetStart, *callEditor, *callFilter, *callLine,
           *showMsg, *showNet, *alignTop, *alignBottom, *alignLeft, *alignRight,
           *distrHor, *distrVert, *selectAll, *callLib, *callMatch, *changeProps,
-          *addToProj, *editFind, *editFindAgain, *insEntity, *selectMarker;
+          *addToProj, *editFind, *editFindAgain, *insEntity, *selectMarker,
+          *createLib, *importData, *graph2csv, *createPkg, *extractPkg,
+          *callAtt, *centerHor, *centerVert;
 
 public slots:
   void slotEditRotate(bool);  // rotate the selected items
@@ -266,6 +277,8 @@ public slots:
   void slotAlignRight();  // align selected elements with respect to right
   void slotDistribHoriz();// distribute horizontally selected elements
   void slotDistribVert(); // distribute vertically selected elements
+  void slotCenterHorizontal();
+  void slotCenterVertical();
   void slotSelectAll();
   void slotSelectMarker();
   void slotShowLastMsg();
@@ -275,6 +288,7 @@ public slots:
   void slotCallLine();
   void slotCallLibrary();
   void slotCallMatch();
+  void slotCallAtt();
   void slotHelpIndex();       // shows a HTML docu: Help Index
   void slotGettingStarted();  // shows a HTML docu: Getting started
   void slotChangeProps();
@@ -287,9 +301,15 @@ private slots:
   void slotCursorUp();
   void slotCursorDown();
   void slotResizePropEdit(const QString&);
+  void slotCreateLib();
+  void slotImportData();
+  void slotExportGraphAsCsv();
+  void slotCreatePackage();
+  void slotExtractPackage();
 
 private:
   void showHTML(const QString&);
   bool performToggleAction(bool, QAction*, pToggleFunc, pMouseFunc, pMouseFunc2);
+  friend class SaveDialog;
 };
 #endif
