@@ -504,9 +504,11 @@ void Schematic::print(QPrinter*, QPainter *Painter, bool printAll, bool fitToPag
     if(UsedY1 > 0)  StartY = 0;
   }
 
+  float PrintRatio = printerDpiX / screenDpiX;
   QFont oldFont = Painter->font();
-  p.init(Painter, PrintScale * printerDpiX / screenDpiX,
-         -StartX, -StartY, -marginX, -marginY, PrintScale);
+  p.init(Painter, PrintScale * PrintRatio,
+         -StartX, -StartY, -marginX, -marginY,
+	 PrintScale, PrintRatio);
 
   if(!symbolMode)
     paintFrame(&p);
@@ -515,7 +517,11 @@ void Schematic::print(QPrinter*, QPainter *Painter, bool printAll, bool fitToPag
     if(pc->isSelected || printAll) {
       selected = pc->isSelected;
       pc->isSelected = false;
+#ifdef __MINGW32__
+      pc->print(&p, 1.0);
+#else
       pc->print(&p, screenDpiX / printerDpiX);
+#endif
       pc->isSelected = selected;
     }
 
@@ -1170,7 +1176,10 @@ int Schematic::save()
   int result = adjustPortNumbers();// same port number for schematic and symbol
   if(saveDocument() < 0)
      return -1;
-  lastSaved = QDateTime::currentDateTime();
+
+  QFileInfo Info(DocName);
+  lastSaved = Info.lastModified();
+
   if(result >= 0) {
     setChanged(false);
     QString *p, *ps = UndoStack.current();
@@ -1292,7 +1301,7 @@ bool Schematic::undo()
   if(ps != UndoStack.getLast())  App->redo->setEnabled(true);
   else  App->redo->setEnabled(false);
 
-  if(ps->at(1) == 'i')
+  if(ps->at(1) == 'i') {
     if(UndoSymbol.isEmpty()) {
       setChanged(false, false);
       return true;
@@ -1301,6 +1310,7 @@ bool Schematic::undo()
       setChanged(false, false);
       return true;
     }
+  }
 
   setChanged(true, false);
   return true;
@@ -1344,7 +1354,7 @@ bool Schematic::redo()
   if(ps != UndoStack.getLast())  App->redo->setEnabled(true);
   else  App->redo->setEnabled(false);
 
-  if(ps->at(1) == 'i')
+  if(ps->at(1) == 'i') {
     if(UndoSymbol.isEmpty()) {
       setChanged(false, false);
       return true;
@@ -1353,6 +1363,7 @@ bool Schematic::redo()
       setChanged(false, false);
       return true;
     }
+  }
 
   setChanged(true, false);
   return true;
