@@ -44,7 +44,7 @@ public:
   void setName(const QString&);
   void setChanged(bool, bool fillStack=false, char Op='*');
   void paintGrid(ViewPainter*, int, int, int, int);
-  void print(QPrinter*, bool);
+  void print(QPrinter*, QPainter*, bool, bool);
 
   float textCorr();
   void  sizeOfAll(int&, int&, int&, int&);
@@ -55,12 +55,14 @@ public:
   bool  elementsOnGrid();
 
   float zoom(float);
+  float zoomBy(float);
   void  showAll();
   void  showNoZoom();
   void  enlargeView(int, int, int, int);
   void  switchPaintMode();
   int   adjustPortNumbers();
   void  reloadGraphs();
+  bool  createSubcircuitSymbol();
 
   QString copySelected(bool);
   bool    paste(QTextStream*, QPtrList<Element>*);
@@ -91,6 +93,9 @@ public:
   int ViewX1, ViewY1, ViewX2, ViewY2;  // size of the document area
   int UsedX1, UsedY1, UsedX2, UsedY2;  // document area used by elements
 
+  int showFrame;
+  QString Frame_Text0, Frame_Text1, Frame_Text2, Frame_Text3;
+
   // Two of those data sets are needed for Schematic and for symbol.
   // Which one is in "tmp..." depends on "symbolMode".
   float tmpScale;
@@ -101,6 +106,8 @@ public:
   QPtrList<QString> UndoSymbol;    // undo stack for circuit symbol
 
 protected:
+  void paintFrame(ViewPainter*);
+
   // overloaded function to get actions of user
   void drawContents(QPainter*, int, int, int, int);
   void contentsMouseMoveEvent(QMouseEvent*);
@@ -122,7 +129,6 @@ protected slots:
 private:
   bool dragIsOkay;
 
-
 /* ********************************************************************
    *****  The following methods are in the file                   *****
    *****  "schematic_element.cpp". They only access the QPtrList  *****
@@ -151,11 +157,11 @@ public:
   void    markerLeftRight(bool, QPtrList<Element>*);
   void    markerUpDown(bool, QPtrList<Element>*);
 
-  Element* selectElement(int, int, bool, int *index=0);
+  Element* selectElement(float, float, bool, int *index=0);
   void     deselectElements(Element*);
   int      selectElements(int, int, int, int, bool);
   void     selectMarkers();
-  void     newMovingWires(QPtrList<Element>*, Node*);
+  void     newMovingWires(QPtrList<Element>*, Node*, int);
   int      copySelectedElements(QPtrList<Element>*);
   bool     deleteElements();
   bool     aligning(int);
@@ -181,7 +187,7 @@ public:
   void     insertNodeLabel(WireLabel*);
   void     copyLabels(int&, int&, int&, int&, QPtrList<Element>*);
 
-  Painting* selectedPainting(int, int);
+  Painting* selectedPainting(float, float);
   void      copyPaintings(int&, int&, int&, int&, QPtrList<Element>*);
 
 private:
@@ -200,14 +206,15 @@ private:
    ******************************************************************** */
 
 public:
+  bool createLibNetlist(QTextStream*, QTextEdit*, int);
   bool createSubNetlist(QTextStream*, int&, QStringList&, QTextEdit*, int);
+  void createSubNetlistPlain(QTextStream*, QTextEdit*, int);
   int  prepareNetlist(QTextStream&, QStringList&, QTextEdit*);
   QString createNetlist(QTextStream&, int);
-
+  bool loadDocument();
 
 private:
   int  saveDocument();
-  bool loadDocument();
 
   bool loadProperties(QTextStream*);
   void simpleInsertComponent(Component*);
@@ -231,6 +238,10 @@ private:
   bool giveNodeNames(QTextStream*, int&, QStringList&, QTextEdit*, int);
 
   QStringList Signals; // collecting node names for VHDL signal declarations
+
+public:
+  bool isVerilog;
+  bool creatingLib;
 };
 
 #endif
